# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui5/devicesetupdialog_base.ui'
#
# Created by: PyQt5 UI code generator 5.4.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(700, 500)
        self.gridlayout = QtWidgets.QGridLayout(Dialog)
        self.gridlayout.setObjectName("gridlayout")
        self.label = QtWidgets.QLabel(Dialog)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.gridlayout.addWidget(self.label, 0, 0, 1, 1)
        self.line = QtWidgets.QFrame(Dialog)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.gridlayout.addWidget(self.line, 1, 0, 1, 3)
        self.DeviceComboBox = DeviceUriComboBox(Dialog)
        self.DeviceComboBox.setObjectName("DeviceComboBox")
        self.gridlayout.addWidget(self.DeviceComboBox, 2, 0, 1, 3)
        self.TabWidget = QtWidgets.QTabWidget(Dialog)
        self.TabWidget.setObjectName("TabWidget")
        self.PowerSettingsTab = QtWidgets.QWidget()
        self.PowerSettingsTab.setObjectName("PowerSettingsTab")
        self.gridlayout1 = QtWidgets.QGridLayout(self.PowerSettingsTab)
        self.gridlayout1.setObjectName("gridlayout1")
        self.groupBox = QtWidgets.QGroupBox(self.PowerSettingsTab)
        self.groupBox.setObjectName("groupBox")
        self.gridlayout2 = QtWidgets.QGridLayout(self.groupBox)
        self.gridlayout2.setObjectName("gridlayout2")
        self.OnRadioButton = QtWidgets.QRadioButton(self.groupBox)
        self.OnRadioButton.setObjectName("OnRadioButton")
        self.gridlayout2.addWidget(self.OnRadioButton, 0, 0, 1, 2)
        self.hboxlayout = QtWidgets.QHBoxLayout()
        self.hboxlayout.setObjectName("hboxlayout")
        self.OffRadioButton = QtWidgets.QRadioButton(self.groupBox)
        self.OffRadioButton.setEnabled(True)
        self.OffRadioButton.setObjectName("OffRadioButton")
        self.hboxlayout.addWidget(self.OffRadioButton)
        self.DurationComboBox = QtWidgets.QComboBox(self.groupBox)
        self.DurationComboBox.setEnabled(False)
        self.DurationComboBox.setObjectName("DurationComboBox")
        self.hboxlayout.addWidget(self.DurationComboBox)
        self.gridlayout2.addLayout(self.hboxlayout, 1, 0, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout2.addItem(spacerItem, 1, 1, 1, 1)
        self.gridlayout1.addWidget(self.groupBox, 0, 0, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(282, 51, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridlayout1.addItem(spacerItem1, 1, 0, 1, 1)
        self.TabWidget.addTab(self.PowerSettingsTab, "")
        self.gridlayout.addWidget(self.TabWidget, 3, 0, 1, 3)
        spacerItem2 = QtWidgets.QSpacerItem(510, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        self.gridlayout.addItem(spacerItem2, 4, 0, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(361, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout.addItem(spacerItem3, 5, 0, 1, 1)
        self.CancelButton = QtWidgets.QPushButton(Dialog)
        self.CancelButton.setObjectName("CancelButton")
        self.gridlayout.addWidget(self.CancelButton, 5, 2, 1, 1)

        self.retranslateUi(Dialog)
        self.TabWidget.setCurrentIndex(0)
        self.OffRadioButton.toggled['bool'].connect(self.DurationComboBox.setEnabled)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "HP Device Manager - Device Setup"))
        self.label.setText(_translate("Dialog", "Device Setup"))
        self.groupBox.setTitle(_translate("Dialog", "Automatic Power Off"))
        self.OnRadioButton.setText(_translate("Dialog", "Always leave printer on"))
        self.OffRadioButton.setText(_translate("Dialog", "Automatically turn printer off after:"))
        self.TabWidget.setTabText(self.TabWidget.indexOf(self.PowerSettingsTab), _translate("Dialog", "Power Settings"))
        self.CancelButton.setText(_translate("Dialog", "Close"))

from .deviceuricombobox import DeviceUriComboBox



# -*- coding: utf-8 -*-
#
# (c) Copyright 2001-2015 HP Development Company, L.P.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# Author: Don Welch
#

# Local
from base.g import *
from base.codes import *
from base.sixext import  to_unicode
from .ui_utils import *

# Qt
from PyQt5.QtCore import *
from PyQt5.QtGui import *
from .settingsdialog_base import Ui_SettingsDialog_base



class SettingsDialog(QDialog, Ui_SettingsDialog_base):
    def __init__(self, parent=None):
        QDialog.__init__(self, parent)
        self.setupUi(self)

        self.SetDefaultsButton.clicked.connect(self.SetDefaultsButton_clicked)

        self.user_settings = UserSettings()
        self.user_settings.load()
        
        cur_vers = sys_conf.get('hplip', 'version')
        last_ver = user_conf.get('upgrade','latest_available_version')
        if utils.Is_HPLIP_older_version(cur_vers, last_ver):
            upgrade_msg ="Currently HPLIP-%s version is installed.\nLatest HPLIP-%s version is available for installation"%(cur_vers, last_ver)
        else:
            upgrade_msg ="HPLIP-%s version is installed"%(cur_vers)
            
        self.SystemTraySettings.initUi(self.user_settings.systray_visible,
                                       self.user_settings.polling,
                                       self.user_settings.polling_interval,
                                       self.user_settings.device_list,
                                       self.user_settings.systray_messages,
                                       self.user_settings.upgrade_notify,
                                       self.user_settings.upgrade_pending_update_time,
                                       upgrade_msg)

        self.updateControls()


    def updateControls(self):
        self.AutoRefreshCheckBox.setChecked(self.user_settings.auto_refresh)
        self.AutoRefreshRateSpinBox.setValue(self.user_settings.auto_refresh_rate) # min
        if self.user_settings.auto_refresh_type == 1:
            self.RefreshCurrentRadioButton.setChecked(True)
        else:
            self.RefreshAllRadioButton.setChecked(True)

        self.ScanCommandLineEdit.setText(self.user_settings.cmd_scan)
        self.SystemTraySettings.systray_visible = self.user_settings.systray_visible
        self.SystemTraySettings.systray_messages = self.user_settings.systray_messages
        self.SystemTraySettings.upgrade_notify = self.user_settings.upgrade_notify
        self.SystemTraySettings.updateUi()


    def updateData(self):
        self.user_settings.systray_visible = self.SystemTraySettings.systray_visible
        self.user_settings.systray_messages = self.SystemTraySettings.systray_messages
        self.user_settings.cmd_scan = to_unicode(self.ScanCommandLineEdit.text())
        self.user_settings.auto_refresh = bool(self.AutoRefreshCheckBox.isChecked())
        self.user_settings.upgrade_notify = self.SystemTraySettings.upgrade_notify

        if self.RefreshCurrentRadioButton.isChecked():
            self.user_settings.auto_refresh_type = 1
        else:
            self.user_settings.auto_refresh_type = 2

        self.user_settings.auto_refresh_rate = self.AutoRefreshRateSpinBox.value()


    def SetDefaultsButton_clicked(self):
        self.user_settings.loadDefaults()
        self.updateControls()


    def accept(self):
        self.updateData()
        self.user_settings.save()
        QDialog.accept(self)

        # TODO: Need a way to signal hp-systray if systray_visible has changed

    def __tr(self,s,c = None):
        return qApp.translate("SettingsDialog",s,c)





# -*- coding: utf-8 -*-
#
# (c) Copyright 2001-2015 HP Development Company, L.P.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# Authors: Don Welch
#

# StdLib
import os.path

# Local
from base.g import *
from base import device
from prnt import cups
from base.codes import *
from base.sixext import  to_unicode
from .ui_utils import *

# Qt
from PyQt5.QtCore import *
from PyQt5.QtGui import *

# Ui
from .infodialog_base import Ui_Dialog
from .deviceuricombobox import DEVICEURICOMBOBOX_TYPE_PRINTER_AND_FAX


class InfoDialog(QDialog, Ui_Dialog):
    def __init__(self, parent, device_uri):
        QDialog.__init__(self, parent)
        self.device_uri = device_uri
        #self.tabs = []
        self.setupUi(self)
        self.initUi()

        QTimer.singleShot(0, self.updateUi)


    def initUi(self):
        # connect signals/slots
        self.CancelButton.clicked.connect(self.CancelButton_clicked)
        self.DeviceComboBox.DeviceUriComboBox_noDevices.connect(self.DeviceUriComboBox_noDevices)
        self.DeviceComboBox.DeviceUriComboBox_currentChanged.connect(self.DeviceUriComboBox_currentChanged)

        # Application icon
        self.setWindowIcon(QIcon(load_pixmap('hp_logo', '128x128')))

        if self.device_uri:
            self.DeviceComboBox.setInitialDevice(self.device_uri)

        self.DeviceComboBox.setType(DEVICEURICOMBOBOX_TYPE_PRINTER_AND_FAX)

        self.headers = [self.__tr("Key"), self.__tr("Value")]
        self.history_headers = [self.__tr("Date/Time"), None,
                                self.__tr("Event Code"), self.__tr("Description"),
                                self.__tr("User"), self.__tr("CUPS Job ID"),
                                self.__tr("Doc. Title")]


    def updateUi(self):
        self.DeviceComboBox.updateUi()
        #self.updateInfoTable()


    def updateInfoTable(self):
        QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
        self.DynamicTableWidget.clear()
        self.DynamicTableWidget.setRowCount(0)
        self.DynamicTableWidget.setColumnCount(0)
        flags = Qt.ItemIsSelectable | Qt.ItemIsEnabled

        while self.TabWidget.count() > 3:
            self.TabWidget.removeTab(3)

        self.DynamicTableWidget.clear()
        self.DynamicTableWidget.setRowCount(0)
        self.DynamicTableWidget.setColumnCount(len(self.headers))
        self.DynamicTableWidget.setHorizontalHeaderLabels(self.headers)

        #
        # Static Data
        #

        try:
            d = device.Device(self.device_uri, None)
        except Error:
            QApplication.restoreOverrideCursor()
            FailureUI(self, self.__tr("<b>Unable to open device %s.</b>"%(self.device_uri)))
            #self.close()
            return

        self.StaticTableWidget.clear()

        self.StaticTableWidget.setColumnCount(len(self.headers))
        self.StaticTableWidget.setHorizontalHeaderLabels(self.headers)

        mq_keys = list(d.mq.keys())
        mq_keys.sort()

        self.StaticTableWidget.setRowCount(len(mq_keys))

        for row, key in enumerate(mq_keys):
            i = QTableWidgetItem(str(key))
            i.setFlags(flags)
            self.StaticTableWidget.setItem(row, 0, i)

            i = QTableWidgetItem(str(d.mq[key]))
            i.setFlags(flags)
            self.StaticTableWidget.setItem(row, 1, i)

        self.StaticTableWidget.resizeColumnToContents(0)
        self.StaticTableWidget.resizeColumnToContents(1)
        self.StaticTableWidget.setSortingEnabled(True)
        self.StaticTableWidget.sortItems(0)

        #
        # Dynamic Data
        #

        try:
            try:
                d.open()
                d.queryDevice()
            except Error as e:
                QApplication.restoreOverrideCursor()
                FailureUI(self, self.__tr("<b>Unable to open device %s.</b>"%(self.device_uri)))
                #self.close()
                return

            dq_keys = list(d.dq.keys())
            dq_keys.sort()

            self.DynamicTableWidget.setRowCount(len(dq_keys))

            for row, key in enumerate(dq_keys):
                i = QTableWidgetItem(str(key))
                i.setFlags(flags)
                self.DynamicTableWidget.setItem(row, 0, i)

                i = QTableWidgetItem(str(d.dq[key]))
                i.setFlags(flags)
                self.DynamicTableWidget.setItem(row, 1, i)


            self.DynamicTableWidget.resizeColumnToContents(0)
            self.DynamicTableWidget.resizeColumnToContents(1)
            self.DynamicTableWidget.setSortingEnabled(True)
            self.DynamicTableWidget.sortItems(0)

        finally:
            d.close()

        #
        # History Table
        #

        self.HistoryTableWidget.clear()
        self.HistoryTableWidget.setRowCount(0)

        if d.device_type == DEVICE_TYPE_FAX:
            self.history_headers[1] = self.__tr("Fax")
        else:
            self.history_headers[1] = self.__tr("Printer")

        self.HistoryTableWidget.setColumnCount(len(self.history_headers))
        self.HistoryTableWidget.setHorizontalHeaderLabels(self.history_headers)

        history = d.queryHistory()
        history.reverse()
        self.HistoryTableWidget.setRowCount(len(history))

        for row, h in enumerate(history):
            dt = QDateTime()
            dt.setTime_t(int(h.timedate))
            dt = value_str(dt)

            ess = device.queryString(h.event_code, 0)

            for col, t in enumerate([dt, h.printer_name,
                           to_unicode(h.event_code), ess,
                           h.username, to_unicode(h.job_id),
                           h.title]):

                i = QTableWidgetItem(str(t))
                i.setFlags(flags)
                self.HistoryTableWidget.setItem(row, col, i)

        self.HistoryTableWidget.resizeColumnToContents(0)
        self.HistoryTableWidget.resizeColumnToContents(1)
        self.HistoryTableWidget.setSortingEnabled(True)
        self.HistoryTableWidget.sortItems(0)

        #
        # Printer Data
        #

        printers = cups.getPrinters()

        for p in printers:
            if p.device_uri == self.device_uri:
                Tab = QWidget()
                Tab.setObjectName(str(p.name))

                GridLayout = QGridLayout(Tab)
                GridLayout.setObjectName(str("GridLayout-%s" % p.name))

                Table = QTableWidget(Tab)
                Table.setAlternatingRowColors(True)
                Table.setSelectionMode(QAbstractItemView.SingleSelection)
                Table.setSelectionBehavior(QAbstractItemView.SelectRows)
                Table.setVerticalScrollMode(QAbstractItemView.ScrollPerItem)
                Table.setHorizontalScrollMode(QAbstractItemView.ScrollPerPixel)
                Table.setGridStyle(Qt.DotLine)
                Table.setObjectName(str("Table-%s" % p.name))
                GridLayout.addWidget(Table, 0, 0, 1, 1)
                self.TabWidget.addTab(Tab, str(p.name))

                Table.setColumnCount(len(self.headers))
                Table.setHorizontalHeaderLabels(self.headers)

                cups.resetOptions()
                cups.openPPD(p.name)
                current_options = dict(cups.getOptions())

                #current_options['cups_error_log_level'] = cups.getErrorLogLevel()

                try:
                    f = open(os.path.expanduser('~/.cups/lpoptions'))
                except IOError as e:
                    log.debug(str(e))
                    current_options['lpoptions_file_data'] = str("(%s)"%str(e))
                else:
                    text = f.read()
                    for d in text.splitlines():
                        if p.name in d:
                            current_options['lpoptions_file_data'] = d
                            break
                    else:
                        current_options['lpoptions_file_data'] = self.__tr("(no data)")

                keys = list(current_options.keys())
                keys.sort()

                Table.setRowCount(len(keys))

                for row, key in enumerate(keys):
                    i = QTableWidgetItem(str(key))
                    i.setFlags(flags)
                    Table.setItem(row, 0, i)

                    if key == 'printer-state':
                        state = int(current_options[key])
                        if state == cups.IPP_PRINTER_STATE_IDLE:
                            i = QTableWidgetItem(self.__tr("idle (%s)"%state))
                        elif state == cups.IPP_PRINTER_STATE_PROCESSING:
                            i = QTableWidgetItem(self.__tr("busy/printing (%s)"%state))
                        elif state == cups.IPP_PRINTER_STATE_STOPPED:
                            i = QTableWidgetItem(self.__tr("stopped (%s)"%state))
                        else:
                            i = QTableWidgetItem(str(state))
                    else:
                        i = QTableWidgetItem(str(current_options[key]))

                    i.setFlags(flags)
                    Table.setItem(row, 1, i)

                Table.resizeColumnToContents(0)
                Table.resizeColumnToContents(1)
                Table.setSortingEnabled(True)
                Table.sortItems(0)

        cups.closePPD()
        self.TabWidget.setCurrentIndex(0)
        QApplication.restoreOverrideCursor()


    def DeviceUriComboBox_currentChanged(self, device_uri):
        self.device_uri = device_uri
        self.updateInfoTable()


    def DeviceUriComboBox_noDevices(self):
        FailureUI(self, self.__tr("<b>No devices found.</b>"))
        self.close()


    def CancelButton_clicked(self):
        self.close()

    #
    # Misc
    #

    def __tr(self,s,c = None):
        return qApp.translate("InfoDialog",s,c)





# -*- coding: utf-8 -*-
#
# (c) Copyright 2001-2015 HP Development Company, L.P.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# Authors: Don Welch
#

# StdLib
import operator
import signal

# Local
from base.g import *
from base import device, utils
from prnt import cups
from base.codes import *
from .ui_utils import *
from base.sixext import to_unicode
# Qt
from PyQt5.QtCore import *
from PyQt5.QtGui import *
from PyQt5.QtWidgets import *

# Ui
from .faxsetupdialog_base import Ui_Dialog
from .deviceuricombobox import DEVICEURICOMBOBOX_TYPE_FAX_ONLY

fax_enabled = prop.fax_build

if fax_enabled:
    try:
        from fax import fax
    except ImportError:
        # This can fail on Python < 2.3 due to the datetime module
        # or if fax was diabled during the build
        fax_enabled = False

if not fax_enabled:
    log.warn("Fax disabled.")

class PasswordDialog(QDialog):
    def __init__(self, prompt, parent=None, name=None, modal=0, fl=0):
        QDialog.__init__(self, parent)
        # Application icon
        self.setWindowIcon(QIcon(load_pixmap('hp_logo', '128x128')))
        self.prompt = prompt

        Layout = QGridLayout(self)
        Layout.setContentsMargins(11, 11, 11, 11)
        Layout.setSpacing(6)

        self.PromptTextLabel = QLabel(self)
        Layout.addWidget(self.PromptTextLabel, 0, 0, 1, 3)

        self.UsernameTextLabel = QLabel(self)
        Layout.addWidget(self.UsernameTextLabel, 1, 0)

        self.UsernameLineEdit = QLineEdit(self)
        self.UsernameLineEdit.setEchoMode(QLineEdit.Normal)
        Layout.addWidget(self.UsernameLineEdit, 1, 1, 1, 2)

        self.PasswordTextLabel = QLabel(self)
        Layout.addWidget(self.PasswordTextLabel, 2, 0)

        self.PasswordLineEdit = QLineEdit(self)
        self.PasswordLineEdit.setEchoMode(QLineEdit.Password)
        Layout.addWidget(self.PasswordLineEdit, 2, 1, 1, 2)

        self.OkPushButton = QPushButton(self)
        Layout.addWidget(self.OkPushButton, 3, 2)

        self.CancelPushButton = QPushButton(self)
        Layout.addWidget(self.CancelPushButton, 3, 1)

        self.languageChange()

        self.resize(QSize(420, 163).expandedTo(self.minimumSizeHint()))

        self.OkPushButton.clicked.connect(self.accept)
        self.CancelPushButton.clicked.connect(self.reject)
        self.PasswordLineEdit.returnPressed.connect(self.accept)

    def setDefaultUsername(self, defUser, allowUsernameEdit=True):
        self.UsernameLineEdit.setText(defUser)
        if not allowUsernameEdit:
            self.UsernameLineEdit.setReadOnly(True)
            self.UsernameLineEdit.setStyleSheet(
                "QLineEdit {background-color: lightgray}")

    def getUsername(self):
        return to_unicode(self.UsernameLineEdit.text())

    def getPassword(self):
        return to_unicode(self.PasswordLineEdit.text())

    def languageChange(self):
        self.setWindowTitle(
            self.__tr("HP Device Manager - Enter Username/Password"))
        self.PromptTextLabel.setText(self.__tr(self.prompt))
        self.UsernameTextLabel.setText(self.__tr("Username:"))
        self.PasswordTextLabel.setText(self.__tr("Password:"))
        self.OkPushButton.setText(self.__tr("OK"))
        self.CancelPushButton.setText(self.__tr("Cancel"))

    def __tr(self, s, c=None):
        return qApp.translate("SetupDialog", s, c)


def FailureMessageUI(prompt):
    try:
        dlg = PasswordDialog(prompt, None)
        FailureUI(dlg, prompt)
    finally:
        pass


def showPasswordUI(prompt, userName=None, allowUsernameEdit=True):
    try:
        dlg = PasswordDialog(prompt, None)

        if userName != None:
            dlg.setDefaultUsername(userName, allowUsernameEdit)

        if dlg.exec_() == QDialog.Accepted:
            return (dlg.getUsername(), dlg.getPassword())

    finally:
        pass

    return ("", "")

class FaxSetupDialog(QDialog, Ui_Dialog):
    def __init__(self, parent, device_uri):
        QDialog.__init__(self, parent)
        self.setupUi(self)
        self.device_uri = device_uri
        self.initUi()
        self.dev = None
        self.fax_number = ''
        self.fax_company_name = ''
        self.call_password_ui = True
        self.user_settings = UserSettings()
        self.user_settings.load()
        self.user_settings.debug()

        QTimer.singleShot(0, self.updateUi)

    def initUi(self):
        # connect signals/slots
        self.CancelButton.clicked.connect(self.CancelButton_clicked)
        self.SaveBtn.clicked.connect(self.SaveBtn_Clicked)
        self.FaxComboBox.DeviceUriComboBox_noDevices.connect(
            self.FaxComboBox_noDevices)
        self.FaxComboBox.DeviceUriComboBox_currentChanged.connect(
            self.FaxComboBox_currentChanged)
        self.FaxComboBox.setType(DEVICEURICOMBOBOX_TYPE_FAX_ONLY)
        signal.signal(signal.SIGINT, signal.SIG_DFL)

        # Application icon
        self.setWindowIcon(QIcon(load_pixmap('hp_logo', '128x128')))

        if self.device_uri:
            self.FaxComboBox.setInitialDevice(self.device_uri)

        self.NameCompanyLineEdit.setMaxLength(50)
        self.FaxNumberLineEdit.setMaxLength(50)
        self.FaxNumberLineEdit.setValidator(
            PhoneNumValidator(self.FaxNumberLineEdit))
        self.VoiceNumberLineEdit.setMaxLength(50)
        self.VoiceNumberLineEdit.setValidator(
            PhoneNumValidator(self.VoiceNumberLineEdit))
        self.EmailLineEdit.setMaxLength(50)
        self.fax_number = to_unicode(self.FaxNumberLineEdit.text())
        self.fax_company_name = to_unicode(self.NameCompanyLineEdit.text())
        '''
        self.NameCompanyLineEdit.editingFinished.connect(
            self.NameCompanyLineEdit_editingFinished)
        
        self.NameCompanyLineEdit.textChanged["const QString &"].connect(
            self.NameCompanyLineEdit_textChanged)

        self.FaxNumberLineEdit.editingFinished.connect(
            self.FaxNumberLineEdit_editingFinished)

        self.FaxNumberLineEdit.textChanged["const QString &"].connect(
            self.FaxNumberLineEdit_textChanged)
        '''
        self.VoiceNumberLineEdit.editingFinished.connect(
            self.VoiceNumberLineEdit_editingFinished)

        self.VoiceNumberLineEdit.textChanged["const QString &"].connect(
            self.VoiceNumberLineEdit_textChanged)

        self.EmailLineEdit.editingFinished.connect(
            self.EmailLineEdit_editingFinished)

        self.EmailLineEdit.textChanged["const QString &"].connect(
            self.EmailLineEdit_textChanged)

        self.tabWidget.currentChanged[int].connect(self.Tabs_currentChanged)

        self.name_company_dirty = False
        self.fax_number_dirty = False
        self.voice_number_dirty = False
        self.email_dirty = False

    def updateUi(self):
        if not fax_enabled:
            FailureUI(self, self.__tr(
                "<b>PC send fax support is not enabled.</b><p>Re-install HPLIP with fax support or use the device front panel to send a fax.</p><p>Click <i>OK</i> to exit.</p>"))
            self.close()
            return

        self.FaxComboBox.updateUi()
        self.tabWidget.setCurrentIndex(0)
        self.fax_number = to_unicode(self.FaxNumberLineEdit.text())
        self.fax_company_name = to_unicode(self.NameCompanyLineEdit.text())

    def FaxComboBox_currentChanged(self, device_uri):
        self.device_uri = device_uri
        self.updateCoverpageTab()

        if self.dev is not None:
            self.dev.close()

        try:
            self.dev = fax.getFaxDevice(self.device_uri)
        except Error:
            CheckDeviceUI(self)
            return

        self.updateHeaderTab()

    def FaxComboBox_noDevices(self):
        FailureUI(self, self.__tr(
            "<b>No devices that require fax setup found.</b>"))
        self.close()

    #
    # Name/Company (for TTI header) (stored in device)
    #

    def NameCompanyLineEdit_editingFinished(self):
        self.saveNameCompany(to_unicode(self.NameCompanyLineEdit.text()))

    def NameCompanyLineEdit_textChanged(self, s):
        self.name_company_dirty = True

    def saveNameCompany(self, s):
        self.name_company_dirty = False
        retn = False
        beginWaitCursor()
        try:
            try:
                log.debug("Saving station name %s to device" % s)
                if self.dev.isAuthRequired() == True and self.call_password_ui == True:
                    promptText = "Enter the printer's username password password\n"                    
                    while(True):
                        username, password = showPasswordUI(promptText)
                        if username == '' or password == '':
                            return False
                        respCode = self.dev.getCDMToken(username, password)
                        if respCode != 200:
                            promptText = "Invalid Username or Password!.\nRernter the printer's username password password\n"
                            continue
                        break                
                self.dev.setStationName(s)
                retn = True
            except Error:
                CheckDeviceUI(self)
        finally:
            endWaitCursor()
            return retn

    #
    # Fax Number (for TTI header) (stored in device)
    #

    def FaxNumberLineEdit_editingFinished(self):
        self.saveFaxNumber(to_unicode(self.FaxNumberLineEdit.text()))

    def FaxNumberLineEdit_textChanged(self, s):
        self.fax_number_dirty = True

    def saveFaxNumber(self, s):
        self.fax_number_dirty = False
        retn = False
        beginWaitCursor()
        try:
            try:
                log.debug("Saving fax number %s to device" % s)
                if self.dev.isAuthRequired() == True and self.call_password_ui == True:
                    promptText = "Enter the printer's username password password\n"
                    while(True):
                        username, password = showPasswordUI(promptText)
                        if username == '' or password == '':
                            return retn
                        respCode = self.dev.getCDMToken(username, password)
                        if respCode != 200:
                            promptText = "Invalid Username or Password!.\nRernter the printer's username password password\n"
                            continue
                        break
                self.dev.setPhoneNum(s)
                retn=True
            except Error:
                CheckDeviceUI(self)
        finally:
            endWaitCursor()
            return retn

    #
    # Voice Number (for coverpage) (stored in ~/.hplip/hplip.conf)
    #

    def VoiceNumberLineEdit_editingFinished(self):
        self.saveVoiceNumber(to_unicode(self.VoiceNumberLineEdit.text()))

    def VoiceNumberLineEdit_textChanged(self, s):
        self.voice_number_dirty = True

    def saveVoiceNumber(self, s):
        log.debug("Saving voice number (%s) to ~/.hplip/hplip.conf" % s)
        self.voice_number_dirty = False
        #user_conf.set('fax', 'voice_phone', s)
        self.user_settings.voice_phone = s
        self.user_settings.save()

    #
    # EMail (for coverpage) (stored in ~/.hplip/hplip.conf)
    #

    def EmailLineEdit_editingFinished(self):
        self.saveEmail(to_unicode(self.EmailLineEdit.text()))

    def EmailLineEdit_textChanged(self, s):
        self.email_dirty = True

    def saveEmail(self, s):
        log.debug("Saving email address (%s) to ~/.hplip/hplip.conf" % s)
        self.email_dirty = False
        #user_conf.set('fax', 'email_address', s)
        self.user_settings.email_address = s
        self.user_settings.save()

    #
    #
    #

    def CancelButton_clicked(self):
        self.close()

    def SaveBtn_Clicked(self):

        current_fax_num = self.fax_number = to_unicode(self.FaxNumberLineEdit.text())
        current_fax_company = to_unicode(self.NameCompanyLineEdit.text())
        
        if current_fax_num != self.fax_number:            
            if self.saveFaxNumber(self.fax_number) == False:
                self.FaxNumberLineEdit.setText(current_fax_num)
            else:
                self.fax_number = to_unicode(self.FaxNumberLineEdit.text())
            self.call_password_ui = False

        if  current_fax_company != self.fax_company_name:            
            if self.saveNameCompany(self.fax_company_name) == False:
                self.NameCompanyLineEdit.setText(current_fax_company)
            else:
                self.fax_company_name = to_unicode(self.NameCompanyLineEdit.text())
            self.call_password_ui = False

    def Tabs_currentChanged(self, tab=0):
        """ Called when the active tab changes.
            Update newly displayed tab.
        """
        if tab == 0:
            self.updateHeaderTab()
        elif tab == 1:
            self.updateCoverpageTab()

    def updateHeaderTab(self):
        beginWaitCursor()
        try:
            try:
                name_company = to_unicode(self.dev.getStationName())
                log.debug("name_company = '%s'" % name_company)
                self.NameCompanyLineEdit.setText(name_company)
                fax_number = str(self.dev.getPhoneNum())
                log.debug("fax_number = '%s'" % fax_number)
                self.FaxNumberLineEdit.setText(fax_number)
            except Error:
                CheckDeviceUI(self)
        finally:
            endWaitCursor()

    def updateCoverpageTab(self):
        #voice_phone = user_conf.get('fax', 'voice_phone')
        voice_phone = self.user_settings.voice_phone
        log.debug("voice_phone = '%s'" % voice_phone)
        self.VoiceNumberLineEdit.setText(voice_phone)
        #email_address = user_conf.get('fax', 'email_address')
        email_address = self.user_settings.email_address
        log.debug("email_address = '%s'" % email_address)
        self.EmailLineEdit.setText(email_address)

    def closeEvent(self, e):
        if self.voice_number_dirty:
            self.VoiceNumberLineEdit.editingFinished.emit()
        if self.name_company_dirty:
            self.NameCompanyLineEdit.editingFinished.emit()
        if self.email_dirty:
            self.EmailLineEdit.editingFinished.emit()
        if self.fax_number_dirty:
            self.FaxNumberLineEdit.editingFinished.emit()
        if self.dev is not None:
            self.dev.close()

        e.accept()

    #
    # Misc
    #

    def __tr(self, s, c=None):
        return qApp.translate("FaxSetupDialog", s, c)



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui5/infodialog_base.ui'
#
# Created by: PyQt5 UI code generator 5.4.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(700, 500)
        self.gridlayout = QtWidgets.QGridLayout(Dialog)
        self.gridlayout.setObjectName("gridlayout")
        self.label = QtWidgets.QLabel(Dialog)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.gridlayout.addWidget(self.label, 0, 0, 1, 1)
        self.line = QtWidgets.QFrame(Dialog)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.gridlayout.addWidget(self.line, 1, 0, 1, 2)
        self.DeviceComboBox = DeviceUriComboBox(Dialog)
        self.DeviceComboBox.setObjectName("DeviceComboBox")
        self.gridlayout.addWidget(self.DeviceComboBox, 2, 0, 1, 2)
        self.TabWidget = QtWidgets.QTabWidget(Dialog)
        self.TabWidget.setObjectName("TabWidget")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.gridlayout1 = QtWidgets.QGridLayout(self.tab_2)
        self.gridlayout1.setObjectName("gridlayout1")
        self.StaticTableWidget = QtWidgets.QTableWidget(self.tab_2)
        self.StaticTableWidget.setAlternatingRowColors(True)
        self.StaticTableWidget.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.StaticTableWidget.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.StaticTableWidget.setVerticalScrollMode(QtWidgets.QAbstractItemView.ScrollPerItem)
        self.StaticTableWidget.setHorizontalScrollMode(QtWidgets.QAbstractItemView.ScrollPerPixel)
        self.StaticTableWidget.setGridStyle(QtCore.Qt.DotLine)
        self.StaticTableWidget.setObjectName("StaticTableWidget")
        self.StaticTableWidget.setColumnCount(0)
        self.StaticTableWidget.setRowCount(0)
        self.gridlayout1.addWidget(self.StaticTableWidget, 0, 0, 1, 1)
        self.TabWidget.addTab(self.tab_2, "")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.gridlayout2 = QtWidgets.QGridLayout(self.tab)
        self.gridlayout2.setObjectName("gridlayout2")
        self.DynamicTableWidget = QtWidgets.QTableWidget(self.tab)
        self.DynamicTableWidget.setAlternatingRowColors(True)
        self.DynamicTableWidget.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.DynamicTableWidget.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.DynamicTableWidget.setVerticalScrollMode(QtWidgets.QAbstractItemView.ScrollPerItem)
        self.DynamicTableWidget.setHorizontalScrollMode(QtWidgets.QAbstractItemView.ScrollPerPixel)
        self.DynamicTableWidget.setGridStyle(QtCore.Qt.DotLine)
        self.DynamicTableWidget.setObjectName("DynamicTableWidget")
        self.DynamicTableWidget.setColumnCount(0)
        self.DynamicTableWidget.setRowCount(0)
        self.gridlayout2.addWidget(self.DynamicTableWidget, 0, 0, 1, 1)
        self.TabWidget.addTab(self.tab, "")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.gridlayout3 = QtWidgets.QGridLayout(self.tab_3)
        self.gridlayout3.setObjectName("gridlayout3")
        self.HistoryTableWidget = QtWidgets.QTableWidget(self.tab_3)
        self.HistoryTableWidget.setAlternatingRowColors(True)
        self.HistoryTableWidget.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.HistoryTableWidget.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.HistoryTableWidget.setVerticalScrollMode(QtWidgets.QAbstractItemView.ScrollPerPixel)
        self.HistoryTableWidget.setGridStyle(QtCore.Qt.DotLine)
        self.HistoryTableWidget.setObjectName("HistoryTableWidget")
        self.HistoryTableWidget.setColumnCount(0)
        self.HistoryTableWidget.setRowCount(0)
        self.gridlayout3.addWidget(self.HistoryTableWidget, 0, 0, 1, 1)
        self.TabWidget.addTab(self.tab_3, "")
        self.gridlayout.addWidget(self.TabWidget, 3, 0, 1, 2)
        spacerItem = QtWidgets.QSpacerItem(470, 31, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Maximum)
        self.gridlayout.addItem(spacerItem, 4, 0, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(361, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout.addItem(spacerItem1, 5, 0, 1, 1)
        self.CancelButton = QtWidgets.QPushButton(Dialog)
        self.CancelButton.setObjectName("CancelButton")
        self.gridlayout.addWidget(self.CancelButton, 5, 1, 1, 1)

        self.retranslateUi(Dialog)
        self.TabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "HP Device Manager - Device Information"))
        self.label.setText(_translate("Dialog", "Device Information"))
        self.TabWidget.setTabText(self.TabWidget.indexOf(self.tab_2), _translate("Dialog", "Model Data (Static)"))
        self.TabWidget.setTabText(self.TabWidget.indexOf(self.tab), _translate("Dialog", "Status Data (Dynamic)"))
        self.HistoryTableWidget.setSortingEnabled(False)
        self.TabWidget.setTabText(self.TabWidget.indexOf(self.tab_3), _translate("Dialog", "Status History"))
        self.CancelButton.setText(_translate("Dialog", "Close"))

from .deviceuricombobox import DeviceUriComboBox



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/gaurav/work_qt5/src_qt5/ui5/plugindiagnose_base.ui'
#
# Created by: PyQt5 UI code generator 5.4.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(500, 180)
        self.gridlayout = QtWidgets.QGridLayout(Dialog)
        self.gridlayout.setObjectName("gridlayout")
        self.StackedWidget = QtWidgets.QStackedWidget(Dialog)
        self.StackedWidget.setObjectName("StackedWidget")
        self.page = QtWidgets.QWidget()
        self.page.setObjectName("page")
        self.gridlayout1 = QtWidgets.QGridLayout(self.page)
        self.gridlayout1.setObjectName("gridlayout1")
        self.label = QtWidgets.QLabel(self.page)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.gridlayout1.addWidget(self.label, 0, 0, 1, 1)
        self.line = QtWidgets.QFrame(self.page)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.gridlayout1.addWidget(self.line, 1, 0, 1, 2)
        self.TitleLabel = QtWidgets.QLabel(self.page)
        self.TitleLabel.setWordWrap(True)
        self.TitleLabel.setObjectName("TitleLabel")
        self.gridlayout1.addWidget(self.TitleLabel, 2, 0, 1, 2)
        self.StackedWidget.addWidget(self.page)
        self.gridlayout.addWidget(self.StackedWidget, 0, 0, 1, 4)
        self.line_2 = QtWidgets.QFrame(Dialog)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.gridlayout.addWidget(self.line_2, 1, 0, 1, 4)
        self.NextButton = QtWidgets.QPushButton(Dialog)
        self.NextButton.setEnabled(True)
        self.NextButton.setObjectName("NextButton")
        self.gridlayout.addWidget(self.NextButton, 2, 2, 1, 1)
        self.CancelButton = QtWidgets.QPushButton(Dialog)
        self.CancelButton.setObjectName("CancelButton")
        self.gridlayout.addWidget(self.CancelButton, 2, 3, 1, 1)

        self.retranslateUi(Dialog)
        self.StackedWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "HP Device Manager - Plug-in Installer"))
        self.label.setText(_translate("Dialog", "Driver Plug-in Installation is required"))
        self.TitleLabel.setText(_translate("Dialog", "HP Device requires proprietary plug-in which is missing. Click \'Next\' to continue plug-in installation"))
        self.NextButton.setText(_translate("Dialog", "Next >"))
        self.CancelButton.setText(_translate("Dialog", "Cancel"))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui5/wifisetupdialog_base.ui'
#
# Created by: PyQt5 UI code generator 5.4.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.setWindowModality(QtCore.Qt.ApplicationModal)
        Dialog.resize(700, 500)
        self.gridlayout = QtWidgets.QGridLayout(Dialog)
        self.gridlayout.setObjectName("gridlayout")
        self.StackedWidget = QtWidgets.QStackedWidget(Dialog)
        self.StackedWidget.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.StackedWidget.setObjectName("StackedWidget")
        self.DiscoveryPage = QtWidgets.QWidget()
        self.DiscoveryPage.setObjectName("DiscoveryPage")
        self.gridlayout1 = QtWidgets.QGridLayout(self.DiscoveryPage)
        self.gridlayout1.setObjectName("gridlayout1")
        self.label = QtWidgets.QLabel(self.DiscoveryPage)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.gridlayout1.addWidget(self.label, 0, 0, 1, 3)
        self.line = QtWidgets.QFrame(self.DiscoveryPage)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.gridlayout1.addWidget(self.line, 1, 0, 1, 3)
        self.MainTitleLabel = QtWidgets.QLabel(self.DiscoveryPage)
        self.MainTitleLabel.setWordWrap(True)
        self.MainTitleLabel.setObjectName("MainTitleLabel")
        self.gridlayout1.addWidget(self.MainTitleLabel, 2, 0, 1, 3)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridlayout1.addItem(spacerItem, 3, 1, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout1.addItem(spacerItem1, 4, 0, 1, 1)
        self.Picture = QtWidgets.QLabel(self.DiscoveryPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.Picture.sizePolicy().hasHeightForWidth())
        self.Picture.setSizePolicy(sizePolicy)
        self.Picture.setMinimumSize(QtCore.QSize(396, 128))
        self.Picture.setMaximumSize(QtCore.QSize(396, 128))
        self.Picture.setText("")
        self.Picture.setObjectName("Picture")
        self.gridlayout1.addWidget(self.Picture, 4, 1, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout1.addItem(spacerItem2, 4, 2, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(664, 61, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridlayout1.addItem(spacerItem3, 5, 0, 1, 3)
        self.hboxlayout = QtWidgets.QHBoxLayout()
        self.hboxlayout.setObjectName("hboxlayout")
        self.InfoIcon = QtWidgets.QLabel(self.DiscoveryPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.InfoIcon.sizePolicy().hasHeightForWidth())
        self.InfoIcon.setSizePolicy(sizePolicy)
        self.InfoIcon.setMinimumSize(QtCore.QSize(16, 16))
        self.InfoIcon.setMaximumSize(QtCore.QSize(16, 16))
        self.InfoIcon.setText("")
        self.InfoIcon.setObjectName("InfoIcon")
        self.hboxlayout.addWidget(self.InfoIcon)
        self.label_14 = QtWidgets.QLabel(self.DiscoveryPage)
        self.label_14.setWordWrap(True)
        self.label_14.setObjectName("label_14")
        self.hboxlayout.addWidget(self.label_14)
        self.gridlayout1.addLayout(self.hboxlayout, 6, 0, 1, 3)
        self.StackedWidget.addWidget(self.DiscoveryPage)
        self.page_2 = QtWidgets.QWidget()
        self.page_2.setObjectName("page_2")
        self.gridlayout2 = QtWidgets.QGridLayout(self.page_2)
        self.gridlayout2.setObjectName("gridlayout2")
        self.label_4 = QtWidgets.QLabel(self.page_2)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.label_4.setFont(font)
        self.label_4.setObjectName("label_4")
        self.gridlayout2.addWidget(self.label_4, 0, 0, 1, 2)
        self.line_2 = QtWidgets.QFrame(self.page_2)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.gridlayout2.addWidget(self.line_2, 1, 0, 1, 3)
        self.DevicesTableWidget = QtWidgets.QTableWidget(self.page_2)
        self.DevicesTableWidget.setAlternatingRowColors(True)
        self.DevicesTableWidget.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.DevicesTableWidget.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.DevicesTableWidget.setObjectName("DevicesTableWidget")
        self.DevicesTableWidget.setColumnCount(0)
        self.DevicesTableWidget.setRowCount(0)
        self.gridlayout2.addWidget(self.DevicesTableWidget, 2, 0, 1, 3)
        self.hboxlayout1 = QtWidgets.QHBoxLayout()
        self.hboxlayout1.setObjectName("hboxlayout1")
        self.DevicesFoundIcon = QtWidgets.QLabel(self.page_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.DevicesFoundIcon.sizePolicy().hasHeightForWidth())
        self.DevicesFoundIcon.setSizePolicy(sizePolicy)
        self.DevicesFoundIcon.setMinimumSize(QtCore.QSize(16, 16))
        self.DevicesFoundIcon.setMaximumSize(QtCore.QSize(16, 16))
        self.DevicesFoundIcon.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.DevicesFoundIcon.setText("")
        self.DevicesFoundIcon.setObjectName("DevicesFoundIcon")
        self.hboxlayout1.addWidget(self.DevicesFoundIcon)
        self.DevicesFoundLabel = QtWidgets.QLabel(self.page_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.DevicesFoundLabel.sizePolicy().hasHeightForWidth())
        self.DevicesFoundLabel.setSizePolicy(sizePolicy)
        self.DevicesFoundLabel.setWordWrap(True)
        self.DevicesFoundLabel.setObjectName("DevicesFoundLabel")
        self.hboxlayout1.addWidget(self.DevicesFoundLabel)
        self.gridlayout2.addLayout(self.hboxlayout1, 3, 0, 1, 1)
        spacerItem4 = QtWidgets.QSpacerItem(21, 28, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout2.addItem(spacerItem4, 3, 1, 1, 1)
        self.RefreshButton = QtWidgets.QPushButton(self.page_2)
        self.RefreshButton.setObjectName("RefreshButton")
        self.gridlayout2.addWidget(self.RefreshButton, 3, 2, 1, 1)
        self.StackedWidget.addWidget(self.page_2)
        self.page_3 = QtWidgets.QWidget()
        self.page_3.setObjectName("page_3")
        self.gridlayout3 = QtWidgets.QGridLayout(self.page_3)
        self.gridlayout3.setObjectName("gridlayout3")
        self.label_5 = QtWidgets.QLabel(self.page_3)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.label_5.setFont(font)
        self.label_5.setObjectName("label_5")
        self.gridlayout3.addWidget(self.label_5, 0, 0, 1, 1)
        self.line_3 = QtWidgets.QFrame(self.page_3)
        self.line_3.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_3.setObjectName("line_3")
        self.gridlayout3.addWidget(self.line_3, 1, 0, 1, 1)
        self.groupBox_3 = QtWidgets.QGroupBox(self.page_3)
        self.groupBox_3.setObjectName("groupBox_3")
        self.gridlayout4 = QtWidgets.QGridLayout(self.groupBox_3)
        self.gridlayout4.setObjectName("gridlayout4")
        self.UndirectedRadioButton = QtWidgets.QRadioButton(self.groupBox_3)
        self.UndirectedRadioButton.setChecked(True)
        self.UndirectedRadioButton.setObjectName("UndirectedRadioButton")
        self.gridlayout4.addWidget(self.UndirectedRadioButton, 0, 0, 1, 3)
        self.DirectedRadioButton = QtWidgets.QRadioButton(self.groupBox_3)
        self.DirectedRadioButton.setObjectName("DirectedRadioButton")
        self.gridlayout4.addWidget(self.DirectedRadioButton, 1, 0, 1, 2)
        self.SSIDLineEdit = QtWidgets.QLineEdit(self.groupBox_3)
        self.SSIDLineEdit.setEnabled(False)
        self.SSIDLineEdit.setObjectName("SSIDLineEdit")
        self.gridlayout4.addWidget(self.SSIDLineEdit, 1, 2, 1, 1)
        self.SearchPushButton = QtWidgets.QPushButton(self.groupBox_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.SearchPushButton.sizePolicy().hasHeightForWidth())
        self.SearchPushButton.setSizePolicy(sizePolicy)
        self.SearchPushButton.setObjectName("SearchPushButton")
        self.gridlayout4.addWidget(self.SearchPushButton, 2, 0, 1, 1)
        spacerItem5 = QtWidgets.QSpacerItem(521, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout4.addItem(spacerItem5, 2, 1, 1, 2)
        self.gridlayout3.addWidget(self.groupBox_3, 2, 0, 1, 1)
        self.SelectSSIDGroupBox = QtWidgets.QGroupBox(self.page_3)
        self.SelectSSIDGroupBox.setCheckable(False)
        self.SelectSSIDGroupBox.setObjectName("SelectSSIDGroupBox")
        self.gridlayout5 = QtWidgets.QGridLayout(self.SelectSSIDGroupBox)
        self.gridlayout5.setObjectName("gridlayout5")
        spacerItem6 = QtWidgets.QSpacerItem(421, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout5.addItem(spacerItem6, 0, 0, 1, 2)
        self.ShowExtendedCheckBox = QtWidgets.QCheckBox(self.SelectSSIDGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ShowExtendedCheckBox.sizePolicy().hasHeightForWidth())
        self.ShowExtendedCheckBox.setSizePolicy(sizePolicy)
        self.ShowExtendedCheckBox.setObjectName("ShowExtendedCheckBox")
        self.gridlayout5.addWidget(self.ShowExtendedCheckBox, 0, 2, 1, 1)
        self.NetworksTableWidget = QtWidgets.QTableWidget(self.SelectSSIDGroupBox)
        self.NetworksTableWidget.setAlternatingRowColors(True)
        self.NetworksTableWidget.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.NetworksTableWidget.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.NetworksTableWidget.setVerticalScrollMode(QtWidgets.QAbstractItemView.ScrollPerItem)
        self.NetworksTableWidget.setHorizontalScrollMode(QtWidgets.QAbstractItemView.ScrollPerPixel)
        self.NetworksTableWidget.setObjectName("NetworksTableWidget")
        self.NetworksTableWidget.setColumnCount(0)
        self.NetworksTableWidget.setRowCount(0)
        self.gridlayout5.addWidget(self.NetworksTableWidget, 1, 0, 1, 3)
        self.NetworksFoundIcon = QtWidgets.QLabel(self.SelectSSIDGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.NetworksFoundIcon.sizePolicy().hasHeightForWidth())
        self.NetworksFoundIcon.setSizePolicy(sizePolicy)
        self.NetworksFoundIcon.setMinimumSize(QtCore.QSize(16, 16))
        self.NetworksFoundIcon.setMaximumSize(QtCore.QSize(16, 16))
        self.NetworksFoundIcon.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.NetworksFoundIcon.setText("")
        self.NetworksFoundIcon.setObjectName("NetworksFoundIcon")
        self.gridlayout5.addWidget(self.NetworksFoundIcon, 2, 0, 1, 1)
        self.NetworksFoundLabel = QtWidgets.QLabel(self.SelectSSIDGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.NetworksFoundLabel.sizePolicy().hasHeightForWidth())
        self.NetworksFoundLabel.setSizePolicy(sizePolicy)
        self.NetworksFoundLabel.setWordWrap(True)
        self.NetworksFoundLabel.setObjectName("NetworksFoundLabel")
        self.gridlayout5.addWidget(self.NetworksFoundLabel, 2, 1, 1, 2)
        self.gridlayout3.addWidget(self.SelectSSIDGroupBox, 3, 0, 1, 1)
        self.StackedWidget.addWidget(self.page_3)
        self.page_5 = QtWidgets.QWidget()
        self.page_5.setObjectName("page_5")
        self.gridlayout6 = QtWidgets.QGridLayout(self.page_5)
        self.gridlayout6.setObjectName("gridlayout6")
        self.label_15 = QtWidgets.QLabel(self.page_5)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.label_15.setFont(font)
        self.label_15.setObjectName("label_15")
        self.gridlayout6.addWidget(self.label_15, 0, 0, 1, 2)
        self.line_4 = QtWidgets.QFrame(self.page_5)
        self.line_4.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_4.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_4.setObjectName("line_4")
        self.gridlayout6.addWidget(self.line_4, 1, 0, 1, 2)
        self.hboxlayout2 = QtWidgets.QHBoxLayout()
        self.hboxlayout2.setObjectName("hboxlayout2")
        self.label_3 = QtWidgets.QLabel(self.page_5)
        self.label_3.setObjectName("label_3")
        self.hboxlayout2.addWidget(self.label_3)
        self.SSIDLabel = QtWidgets.QLabel(self.page_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.SSIDLabel.sizePolicy().hasHeightForWidth())
        self.SSIDLabel.setSizePolicy(sizePolicy)
        self.SSIDLabel.setObjectName("SSIDLabel")
        self.hboxlayout2.addWidget(self.SSIDLabel)
        self.StrengthIcon = QtWidgets.QLabel(self.page_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.StrengthIcon.sizePolicy().hasHeightForWidth())
        self.StrengthIcon.setSizePolicy(sizePolicy)
        self.StrengthIcon.setMinimumSize(QtCore.QSize(34, 20))
        self.StrengthIcon.setMaximumSize(QtCore.QSize(34, 20))
        self.StrengthIcon.setText("")
        self.StrengthIcon.setObjectName("StrengthIcon")
        self.hboxlayout2.addWidget(self.StrengthIcon)
        self.gridlayout6.addLayout(self.hboxlayout2, 2, 0, 1, 2)
        spacerItem7 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridlayout6.addItem(spacerItem7, 3, 1, 1, 1)
        self.groupBox = QtWidgets.QGroupBox(self.page_5)
        self.groupBox.setObjectName("groupBox")
        self.gridlayout7 = QtWidgets.QGridLayout(self.groupBox)
        self.gridlayout7.setObjectName("gridlayout7")
        self.WEPRadioButton = ReadOnlyRadioButton(self.groupBox)
        self.WEPRadioButton.setObjectName("WEPRadioButton")
        self.gridlayout7.addWidget(self.WEPRadioButton, 0, 0, 1, 1)
        self.WPARadioButton = ReadOnlyRadioButton(self.groupBox)
        self.WPARadioButton.setObjectName("WPARadioButton")
        self.gridlayout7.addWidget(self.WPARadioButton, 1, 0, 1, 1)
        self.gridlayout6.addWidget(self.groupBox, 4, 0, 1, 2)
        self.groupBox_2 = QtWidgets.QGroupBox(self.page_5)
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridlayout8 = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridlayout8.setObjectName("gridlayout8")
        self.label_6 = QtWidgets.QLabel(self.groupBox_2)
        self.label_6.setObjectName("label_6")
        self.gridlayout8.addWidget(self.label_6, 0, 0, 1, 1)
        self.KeyLineEdit = QtWidgets.QLineEdit(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.KeyLineEdit.sizePolicy().hasHeightForWidth())
        self.KeyLineEdit.setSizePolicy(sizePolicy)
        self.KeyLineEdit.setObjectName("KeyLineEdit")
        self.gridlayout8.addWidget(self.KeyLineEdit, 0, 1, 1, 1)
        self.KeysIcon = QtWidgets.QLabel(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.KeysIcon.sizePolicy().hasHeightForWidth())
        self.KeysIcon.setSizePolicy(sizePolicy)
        self.KeysIcon.setMinimumSize(QtCore.QSize(32, 32))
        self.KeysIcon.setMaximumSize(QtCore.QSize(32, 32))
        self.KeysIcon.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.KeysIcon.setText("")
        self.KeysIcon.setObjectName("KeysIcon")
        self.gridlayout8.addWidget(self.KeysIcon, 0, 2, 1, 1)
        self.ShowKeyCheckBox = QtWidgets.QCheckBox(self.groupBox_2)
        self.ShowKeyCheckBox.setObjectName("ShowKeyCheckBox")
        self.gridlayout8.addWidget(self.ShowKeyCheckBox, 1, 1, 1, 2)
        self.gridlayout6.addWidget(self.groupBox_2, 5, 0, 1, 2)
        spacerItem8 = QtWidgets.QSpacerItem(638, 81, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridlayout6.addItem(spacerItem8, 6, 1, 1, 1)
        self.ConfigureIcon = QtWidgets.QLabel(self.page_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ConfigureIcon.sizePolicy().hasHeightForWidth())
        self.ConfigureIcon.setSizePolicy(sizePolicy)
        self.ConfigureIcon.setMinimumSize(QtCore.QSize(16, 16))
        self.ConfigureIcon.setMaximumSize(QtCore.QSize(16, 16))
        self.ConfigureIcon.setText("")
        self.ConfigureIcon.setObjectName("ConfigureIcon")
        self.gridlayout6.addWidget(self.ConfigureIcon, 7, 0, 1, 1)
        self.label_7 = QtWidgets.QLabel(self.page_5)
        self.label_7.setObjectName("label_7")
        self.gridlayout6.addWidget(self.label_7, 7, 1, 1, 1)
        self.StackedWidget.addWidget(self.page_5)
        self.page = QtWidgets.QWidget()
        self.page.setObjectName("page")
        self.gridlayout9 = QtWidgets.QGridLayout(self.page)
        self.gridlayout9.setObjectName("gridlayout9")
        self.label_16 = QtWidgets.QLabel(self.page)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.label_16.setFont(font)
        self.label_16.setObjectName("label_16")
        self.gridlayout9.addWidget(self.label_16, 0, 0, 1, 1)
        self.line_5 = QtWidgets.QFrame(self.page)
        self.line_5.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_5.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_5.setObjectName("line_5")
        self.gridlayout9.addWidget(self.line_5, 1, 0, 1, 1)
        self.groupBox_4 = QtWidgets.QGroupBox(self.page)
        self.groupBox_4.setObjectName("groupBox_4")
        self.gridlayout10 = QtWidgets.QGridLayout(self.groupBox_4)
        self.gridlayout10.setObjectName("gridlayout10")
        self.label_8 = QtWidgets.QLabel(self.groupBox_4)
        self.label_8.setObjectName("label_8")
        self.gridlayout10.addWidget(self.label_8, 0, 0, 1, 1)
        self.SSIDLabel_2 = QtWidgets.QLabel(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.SSIDLabel_2.sizePolicy().hasHeightForWidth())
        self.SSIDLabel_2.setSizePolicy(sizePolicy)
        self.SSIDLabel_2.setObjectName("SSIDLabel_2")
        self.gridlayout10.addWidget(self.SSIDLabel_2, 0, 1, 1, 1)
        self.hboxlayout3 = QtWidgets.QHBoxLayout()
        self.hboxlayout3.setObjectName("hboxlayout3")
        self.SignalStrengthIcon = QtWidgets.QLabel(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.SignalStrengthIcon.sizePolicy().hasHeightForWidth())
        self.SignalStrengthIcon.setSizePolicy(sizePolicy)
        self.SignalStrengthIcon.setMinimumSize(QtCore.QSize(34, 20))
        self.SignalStrengthIcon.setMaximumSize(QtCore.QSize(34, 20))
        self.SignalStrengthIcon.setObjectName("SignalStrengthIcon")
        self.hboxlayout3.addWidget(self.SignalStrengthIcon)
        self.SignalStrengthLabel = QtWidgets.QLabel(self.groupBox_4)
        self.SignalStrengthLabel.setObjectName("SignalStrengthLabel")
        self.hboxlayout3.addWidget(self.SignalStrengthLabel)
        self.gridlayout10.addLayout(self.hboxlayout3, 0, 2, 1, 1)
        self.label_9 = QtWidgets.QLabel(self.groupBox_4)
        self.label_9.setObjectName("label_9")
        self.gridlayout10.addWidget(self.label_9, 1, 0, 1, 1)
        self.AddressModeLabel = QtWidgets.QLabel(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.AddressModeLabel.sizePolicy().hasHeightForWidth())
        self.AddressModeLabel.setSizePolicy(sizePolicy)
        self.AddressModeLabel.setObjectName("AddressModeLabel")
        self.gridlayout10.addWidget(self.AddressModeLabel, 1, 1, 1, 1)
        self.label_12 = QtWidgets.QLabel(self.groupBox_4)
        self.label_12.setObjectName("label_12")
        self.gridlayout10.addWidget(self.label_12, 2, 0, 1, 1)
        self.HostnameLabel = QtWidgets.QLabel(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.HostnameLabel.sizePolicy().hasHeightForWidth())
        self.HostnameLabel.setSizePolicy(sizePolicy)
        self.HostnameLabel.setObjectName("HostnameLabel")
        self.gridlayout10.addWidget(self.HostnameLabel, 2, 1, 1, 1)
        self.label_10 = QtWidgets.QLabel(self.groupBox_4)
        self.label_10.setObjectName("label_10")
        self.gridlayout10.addWidget(self.label_10, 3, 0, 1, 1)
        self.IPAddressLabel = QtWidgets.QLabel(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.IPAddressLabel.sizePolicy().hasHeightForWidth())
        self.IPAddressLabel.setSizePolicy(sizePolicy)
        self.IPAddressLabel.setObjectName("IPAddressLabel")
        self.gridlayout10.addWidget(self.IPAddressLabel, 3, 1, 1, 1)
        self.label_11 = QtWidgets.QLabel(self.groupBox_4)
        self.label_11.setObjectName("label_11")
        self.gridlayout10.addWidget(self.label_11, 4, 0, 1, 1)
        self.GatewayLabel = QtWidgets.QLabel(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.GatewayLabel.sizePolicy().hasHeightForWidth())
        self.GatewayLabel.setSizePolicy(sizePolicy)
        self.GatewayLabel.setObjectName("GatewayLabel")
        self.gridlayout10.addWidget(self.GatewayLabel, 4, 1, 1, 1)
        self.label_13 = QtWidgets.QLabel(self.groupBox_4)
        self.label_13.setObjectName("label_13")
        self.gridlayout10.addWidget(self.label_13, 5, 0, 1, 1)
        self.DNSLabel = QtWidgets.QLabel(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.DNSLabel.sizePolicy().hasHeightForWidth())
        self.DNSLabel.setSizePolicy(sizePolicy)
        self.DNSLabel.setObjectName("DNSLabel")
        self.gridlayout10.addWidget(self.DNSLabel, 5, 1, 1, 1)
        self.gridlayout9.addWidget(self.groupBox_4, 2, 0, 1, 1)
        self.groupBox_5 = QtWidgets.QGroupBox(self.page)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.groupBox_5.sizePolicy().hasHeightForWidth())
        self.groupBox_5.setSizePolicy(sizePolicy)
        self.groupBox_5.setObjectName("groupBox_5")
        self.gridlayout11 = QtWidgets.QGridLayout(self.groupBox_5)
        self.gridlayout11.setObjectName("gridlayout11")
        self.ExitIcon = QtWidgets.QLabel(self.groupBox_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ExitIcon.sizePolicy().hasHeightForWidth())
        self.ExitIcon.setSizePolicy(sizePolicy)
        self.ExitIcon.setMinimumSize(QtCore.QSize(16, 16))
        self.ExitIcon.setMaximumSize(QtCore.QSize(16, 16))
        self.ExitIcon.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.ExitIcon.setText("")
        self.ExitIcon.setObjectName("ExitIcon")
        self.gridlayout11.addWidget(self.ExitIcon, 0, 0, 1, 1)
        self.ExitLabel = QtWidgets.QLabel(self.groupBox_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ExitLabel.sizePolicy().hasHeightForWidth())
        self.ExitLabel.setSizePolicy(sizePolicy)
        self.ExitLabel.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.ExitLabel.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.ExitLabel.setWordWrap(True)
        self.ExitLabel.setObjectName("ExitLabel")
        self.gridlayout11.addWidget(self.ExitLabel, 0, 1, 2, 2)
        spacerItem9 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridlayout11.addItem(spacerItem9, 1, 0, 1, 1)
        spacerItem10 = QtWidgets.QSpacerItem(501, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout11.addItem(spacerItem10, 2, 0, 1, 2)
        self.hboxlayout4 = QtWidgets.QHBoxLayout()
        self.hboxlayout4.setObjectName("hboxlayout4")
        self.PageLabel2 = QtWidgets.QLabel(self.groupBox_5)
        self.PageLabel2.setObjectName("PageLabel2")
        self.hboxlayout4.addWidget(self.PageLabel2)
        self.PageSpinBox = QtWidgets.QSpinBox(self.groupBox_5)
        self.PageSpinBox.setMinimum(1)
        self.PageSpinBox.setObjectName("PageSpinBox")
        self.hboxlayout4.addWidget(self.PageSpinBox)
        self.PageLabel = QtWidgets.QLabel(self.groupBox_5)
        self.PageLabel.setObjectName("PageLabel")
        self.hboxlayout4.addWidget(self.PageLabel)
        self.gridlayout11.addLayout(self.hboxlayout4, 2, 2, 1, 1)
        self.gridlayout9.addWidget(self.groupBox_5, 3, 0, 1, 1)
        spacerItem11 = QtWidgets.QSpacerItem(664, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridlayout9.addItem(spacerItem11, 4, 0, 1, 1)
        self.StackedWidget.addWidget(self.page)
        self.gridlayout.addWidget(self.StackedWidget, 0, 0, 1, 5)
        self.StepText = QtWidgets.QLabel(Dialog)
        self.StepText.setObjectName("StepText")
        self.gridlayout.addWidget(self.StepText, 1, 0, 1, 1)
        spacerItem12 = QtWidgets.QSpacerItem(181, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout.addItem(spacerItem12, 1, 1, 1, 1)
        self.BackButton = QtWidgets.QPushButton(Dialog)
        self.BackButton.setObjectName("BackButton")
        self.gridlayout.addWidget(self.BackButton, 1, 2, 1, 1)
        self.NextButton = QtWidgets.QPushButton(Dialog)
        self.NextButton.setObjectName("NextButton")
        self.gridlayout.addWidget(self.NextButton, 1, 3, 1, 1)
        self.CancelButton = QtWidgets.QPushButton(Dialog)
        self.CancelButton.setObjectName("CancelButton")
        self.gridlayout.addWidget(self.CancelButton, 1, 4, 1, 1)

        self.retranslateUi(Dialog)
        self.StackedWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "HP Device Manager - Wifi Setup"))
        self.label.setText(_translate("Dialog", "Wireless (Wifi/802.11) Setup"))
        self.MainTitleLabel.setText(_translate("Dialog", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans Serif\'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">This utility allows you configure your wireless capable printer using a temporary USB connection. You will be prompted to disconnect the USB cable once wireless network setup is complete.</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-style:italic;\">Note: Only select wireless capable printers are supported by this utility.</span></p></body></html>"))
        self.label_14.setText(_translate("Dialog", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans Serif\'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Please plug-in your wireless capable printer at this time (using a USB cable) and click<span style=\" font-style:italic;\"> Next &gt;</span> to continue.</p></body></html>"))
        self.label_4.setText(_translate("Dialog", "Select From Discovered Wireless Capable Devices"))
        self.DevicesTableWidget.setSortingEnabled(False)
        self.DevicesFoundLabel.setText(_translate("Dialog", "Found 0 wireless capable devices on the USB bus."))
        self.RefreshButton.setText(_translate("Dialog", "Refresh"))
        self.label_5.setText(_translate("Dialog", "Find and Select a Wireless Network"))
        self.groupBox_3.setTitle(_translate("Dialog", "Find Wireless Network"))
        self.UndirectedRadioButton.setText(_translate("Dialog", "Search for wireless networks automatically"))
        self.DirectedRadioButton.setText(_translate("Dialog", "Enter the name (SSID) of a known wireless network:"))
        self.SearchPushButton.setText(_translate("Dialog", "Search"))
        self.SelectSSIDGroupBox.setTitle(_translate("Dialog", "Wireless Networks"))
        self.ShowExtendedCheckBox.setText(_translate("Dialog", "Show extended information"))
        self.NetworksFoundLabel.setText(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Found %1 wireless networks. Click <span style=\" font-style:italic;\">Search</span> to perform another search.</p></body></html>"))
        self.label_15.setText(_translate("Dialog", "Configure Wireless"))
        self.label_3.setText(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Sans Serif\';\">Wireless Network Name (SSID):</span></p></body></html>"))
        self.SSIDLabel.setText(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Sans Serif\';\">(unknown)</span></p></body></html>"))
        self.groupBox.setTitle(_translate("Dialog", "Wireless Security Type"))
        self.WEPRadioButton.setText(_translate("Dialog", "WEP (Wired Equivalent Privacy)"))
        self.WPARadioButton.setText(_translate("Dialog", "WPA (Wi-Fi Protected Access)"))
        self.groupBox_2.setTitle(_translate("Dialog", "Wireless Security Key"))
        self.label_6.setText(_translate("Dialog", "Key:"))
        self.ShowKeyCheckBox.setText(_translate("Dialog", "Show key"))
        self.label_7.setText(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Sans Serif\'; font-size:9pt;\">Enter the security key for the network, and click </span><span style=\" font-family:\'Sans Serif\'; font-size:9pt; font-style:italic;\">Connect</span><span style=\" font-family:\'Sans Serif\'; font-size:9pt;\"> to continue.</span></p></body></html>"))
        self.label_16.setText(_translate("Dialog", "Wireless Configuration Results"))
        self.groupBox_4.setTitle(_translate("Dialog", "Wireless Configuration"))
        self.label_8.setText(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Sans Serif\'; font-size:9pt;\">Network:</span></p></body></html>"))
        self.SSIDLabel_2.setText(_translate("Dialog", "TextLabel"))
        self.SignalStrengthIcon.setText(_translate("Dialog", "(icon)"))
        self.SignalStrengthLabel.setText(_translate("Dialog", "0/5 (0dBm)"))
        self.label_9.setText(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Sans Serif\'; font-size:9pt;\">Address Mode:</span></p></body></html>"))
        self.AddressModeLabel.setText(_translate("Dialog", "TextLabel"))
        self.label_12.setText(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Sans Serif\'; font-size:9pt;\">Hostname:</span></p></body></html>"))
        self.HostnameLabel.setText(_translate("Dialog", "TextLabel"))
        self.label_10.setText(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Sans Serif\'; font-size:9pt;\">IP Address:</span></p></body></html>"))
        self.IPAddressLabel.setText(_translate("Dialog", "TextLabel"))
        self.label_11.setText(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Sans Serif\'; font-size:9pt;\">Gateway Address:</span></p></body></html>"))
        self.GatewayLabel.setText(_translate("Dialog", "TextLabel"))
        self.label_13.setText(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Sans Serif\'; font-size:9pt;\">DNS Address:</span></p></body></html>"))
        self.DNSLabel.setText(_translate("Dialog", "TextLabel"))
        self.groupBox_5.setTitle(_translate("Dialog", "Messages"))
        self.ExitLabel.setText(_translate("Dialog", "TextLabel"))
        self.PageLabel2.setText(_translate("Dialog", "Message:"))
        self.PageLabel.setText(_translate("Dialog", "of XXX"))
        self.StepText.setText(_translate("Dialog", "Step %1 of %2"))
        self.BackButton.setText(_translate("Dialog", "< Back"))
        self.NextButton.setText(_translate("Dialog", "Next >"))
        self.CancelButton.setText(_translate("Dialog", "Cancel"))

from .readonlyradiobutton import ReadOnlyRadioButton



# -*- coding: utf-8 -*-
#
# (c) Copyright 2001-2015 HP Development Company, L.P.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# Authors: Amarnath Chitumalla
#

#Global
import os
import time
import signal

# Local
from base.g import *
from base import device, utils, pkit, os_utils
from .ui_utils import *

# Qt
from PyQt5.QtCore import *
from PyQt5.QtGui import *

# Ui
from .upgradedialog_base import Ui_Dialog

MANUAL_INSTALL_LINK = "https://developers.hp.com/hp-linux-imaging-and-printing/install/manual/index.html"


class UpgradeDialog(QDialog, Ui_Dialog):
    def __init__(self, parent, distro_tier, msg):
        QDialog.__init__(self, parent)
        self.distro_tier = distro_tier
        self.msg = msg
        self.result = False
        self.setupUi(self, distro_tier, msg)
        self.initUi()


    def initUi(self):
        # connect signals/slots
        self.NextButton.clicked.connect(self.NextButton_clicked)
        self.CancelButton.clicked.connect(self.CancelButton_clicked)
#        self.connect (self.comboBox, SIGNAL ("currentIndexChanged (const QString&)"), self.slotIndexChanged)
        self.installRadioBtton.toggled[bool].connect(self.installRadioBtton_toggled)
        self.remindRadioBtton.toggled[bool].connect(self.remindRadioBtton_toggled)
        self.dontRemindRadioBtton.toggled[bool].connect(self.dontRemindRadioBtton_toggled)
        signal.signal(signal.SIGINT, signal.SIG_DFL)

        # Application icon
        self.setWindowIcon(QIcon(load_pixmap('hp_logo', '128x128')))


    def installRadioBtton_toggled(self, radio_enabled):
        if radio_enabled is True:
            self.installRadioBtton.setChecked(True)
        else:
            self.installRadioBtton.setChecked(False)


    def remindRadioBtton_toggled(self, radio_enabled):
        if radio_enabled is True:
            self.remindRadioBtton.setChecked(True)
            self.daysSpinBox.setEnabled(True)
        else:
            self.remindRadioBtton.setChecked(False)
            self.daysSpinBox.setEnabled(False)


    def dontRemindRadioBtton_toggled(self, radio_enabled):
        if radio_enabled is True:
            self.dontRemindRadioBtton.setChecked(True)
        else:
            self.dontRemindRadioBtton.setChecked(False)


    def NextButton_clicked (self):
        if self.dontRemindRadioBtton.isChecked():
            log.debug("HPLIP Upgrade, selected Don't remind again radiobutton")
            user_conf.set('upgrade', 'notify_upgrade', 'false')
            msg= "Check for HPLIP updates is disabled. To enable it again, change 'Settings' in 'HP systemtray' "
            SuccessUI(self, self.__tr(msg))

        elif self.remindRadioBtton.isChecked():
            schedule_days = str(self.daysSpinBox.value())
            log.debug("HPLIP Upgrade, selected remind later radiobutton  days= %d" %(int(schedule_days)))
            next_time = time.time() + (int(schedule_days) *24 * 60 *60)
            user_conf.set('upgrade', 'pending_upgrade_time', str(int(next_time)))
        else:
            log.debug("HPLIP Upgrade, selected Install radiobutton  distro_type=%d" %self.distro_tier)
            self.NextButton.setEnabled(False)
            if self.distro_tier != 1:     # not tier 1 distro
                log.debug("OK pressed for tier 2 distro pressed")
                utils.openURL(MANUAL_INSTALL_LINK)

                ## TBD::open browser
            else:
                terminal_cmd = utils.get_terminal()
                if terminal_cmd is not None and utils.which("hp-upgrade"):
                    cmd = terminal_cmd + " 'hp-upgrade -w'"
                    os_utils.execute(cmd)
                    self.result = True
                else:
                    log.error("Failed to run hp-upgrade command from terminal =%s "%terminal_cmd)
                    FailureUI(self, self.__tr("Failed to run hp-upgrade"))

        self.close()


    def CancelButton_clicked(self):
        log.debug("User exit")
        self.close()

    def __tr(self,s,c = None):
        return qApp.translate("UpgradeDialog",s,c)




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/gaurav/work_qt5/src_qt5/ui5/pluginlicensedialog_base.ui'
#
# Created by: PyQt5 UI code generator 5.4.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(700, 500)
        self.gridlayout = QtWidgets.QGridLayout(Dialog)
        self.gridlayout.setObjectName("gridlayout")
        self.StackedWidget = QtWidgets.QStackedWidget(Dialog)
        self.StackedWidget.setObjectName("StackedWidget")
        self.page = QtWidgets.QWidget()
        self.page.setObjectName("page")
        self.gridlayout1 = QtWidgets.QGridLayout(self.page)
        self.gridlayout1.setObjectName("gridlayout1")
        self.label = QtWidgets.QLabel(self.page)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.gridlayout1.addWidget(self.label, 0, 0, 1, 1)
        self.line = QtWidgets.QFrame(self.page)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.gridlayout1.addWidget(self.line, 1, 0, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.page)
        self.label_2.setWordWrap(True)
        self.label_2.setObjectName("label_2")
        self.gridlayout1.addWidget(self.label_2, 2, 0, 1, 1)
        self.LicenseTextEdit = QtWidgets.QTextEdit(self.page)
        self.LicenseTextEdit.setAutoFormatting(QtWidgets.QTextEdit.AutoAll)
        self.LicenseTextEdit.setReadOnly(True)
        self.LicenseTextEdit.setTextInteractionFlags(QtCore.Qt.NoTextInteraction)
        self.LicenseTextEdit.setObjectName("LicenseTextEdit")
        self.gridlayout1.addWidget(self.LicenseTextEdit, 3, 0, 1, 1)
        self.AgreeCheckBox = QtWidgets.QCheckBox(self.page)
        self.AgreeCheckBox.setObjectName("AgreeCheckBox")
        self.gridlayout1.addWidget(self.AgreeCheckBox, 4, 0, 1, 1)
        self.StackedWidget.addWidget(self.page)
        self.gridlayout.addWidget(self.StackedWidget, 0, 0, 1, 5)
        self.line_2 = QtWidgets.QFrame(Dialog)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.gridlayout.addWidget(self.line_2, 1, 0, 1, 5)
        spacerItem = QtWidgets.QSpacerItem(161, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout.addItem(spacerItem, 2, 1, 1, 1)
        self.BackButton = QtWidgets.QPushButton(Dialog)
        self.BackButton.setEnabled(False)
        self.BackButton.setObjectName("BackButton")
        self.gridlayout.addWidget(self.BackButton, 2, 2, 1, 1)
        self.NextButton = QtWidgets.QPushButton(Dialog)
        self.NextButton.setEnabled(False)
        self.NextButton.setObjectName("NextButton")
        self.gridlayout.addWidget(self.NextButton, 2, 3, 1, 1)
        self.CancelButton = QtWidgets.QPushButton(Dialog)
        self.CancelButton.setObjectName("CancelButton")
        self.gridlayout.addWidget(self.CancelButton, 2, 4, 1, 1)

        self.retranslateUi(Dialog)
        self.StackedWidget.setCurrentIndex(0)
        self.AgreeCheckBox.toggled['bool'].connect(self.NextButton.setEnabled)
        self.NextButton.clicked.connect(Dialog.accept)
        self.CancelButton.clicked.connect(Dialog.reject)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "HP Device Manager - Plug-in Installer"))
        self.label.setText(_translate("Dialog", "Driver Plug-in License Agreement"))
        self.label_2.setText(_translate("Dialog", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans Serif\'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Please read the driver plug-in license agreement and then check the <span style=\" font-style:italic;\">I agree</span> box and then click <span style=\" font-style:italic;\">Next</span> to continue.</p></body></html>"))
        self.AgreeCheckBox.setText(_translate("Dialog", "I agree to the terms of the driver plug-in license agreement"))
        self.BackButton.setText(_translate("Dialog", "< Back"))
        self.NextButton.setText(_translate("Dialog", "Next >"))
        self.CancelButton.setText(_translate("Dialog", "Cancel"))




# -*- coding: utf-8 -*-
#
# (c) Copyright 2001-2015 HP Development Company, L.P.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# Authors: Don Welch
#


# Local
from base.g import *
#from base import device, utils
from .ui_utils import *

# Qt
from PyQt5.QtCore import *
from PyQt5.QtGui import *

# Ui
from .aboutdialog_base import Ui_AboutDlg_base


class AboutDialog(QDialog, Ui_AboutDlg_base):
    def __init__(self, parent, hplip_version, toolbox_version):
        QDialog.__init__(self, parent)
        self.setupUi(self)
        self.initUi(hplip_version, toolbox_version)


    def initUi(self, hplip_version, toolbox_version):
        self.CloseButton.clicked.connect(self.CloseButton_clicked)

        self.HPLIPVersionText.setText(hplip_version)
        self.ToolboxVersionText.setText(toolbox_version)
        #self.PythonPixmap.setPixmap(load_pixmap('powered_by_python.png'))
        #self.OsiPixmap.setPixmap(load_pixmap('opensource-75x65.png'))
        self.HPLIPLogo.setPixmap(load_pixmap('hp-tux-printer.png'))



    def CloseButton_clicked(self):
        self.close()






#!/usr/local/bin/python3.13
__version__ = '2.2'
__mod__ = 'hp-uiscan'
__title__ = 'Scan Utility'
__doc__ = "SANE-based scan utility for HPLIP supported all-in-one/mfp devices."

from base import utils, module
#from installer import core_install
import os
from math import log
from base.g import *
import operator
try:
    from importlib import import_module
except ImportError as e:
    log.debug(e)
    from base.utils import dyn_import_mod as import_module


#from scan import sane
#import scanext



#mod = module.Module(__mod__, __title__, __version__, __doc__, None, (INTERACTIVE_MODE,))
mod = module.Module(__mod__, __title__, __version__, __doc__, None, (GUI_MODE,), (UI_TOOLKIT_QT4, UI_TOOLKIT_QT5))
mod.setUsage(module.USAGE_FLAG_NONE, extra_options=None, see_also_list = ['hp-scan'])



if __name__ == "__main__":

    opts, device_uri, printer_name, mode, ui_toolkit, lang=mod.parseStdOpts()
    #print (device_uri)
    #device_uri = mod.getDeviceUri(device_uri, printer_name, back_end_filter=['hpaio'], filter={'scan-type': (operator.gt, 0)}, devices=devicelist)
    #print (device_uri)
    '''try:
        #print (device_uri)
        device = sane.openDevice(device_uri)
        #print (device)
    except scanext.error as e:
        #sane.reportError(e.args[0])
        #sys.exit(1)'''


    #k=core_install.CoreInstall()
    #k.get_distro()
    #print k.distro_name
    #print k.distro_version
    #ui_toolkit = k.get_distro_ver_data('ui_toolkit').lower()
    '''if ui_toolkit == 'qt4':
        os.system('python ui4/scan.py')
    elif ui_toolkit == 'qt5':
        os.system('python ui5/scan.py')'''

    QApplication, ui_package = utils.import_dialog(ui_toolkit)

    ui = import_module(ui_package + ".scandialog")

    obj=ui.SetupDialog()
    #obk=obj.setupUi(devicelist)
    obj.setupUi()
    #print obk


    '''list_scanjet=imageprocessing.validate_scanjet_support()
    #print (list_scanjet)
    if(list_scanjet[2] == 'False'):
        scanjet_error="Scanjet features are not supported and disabled for %s %s. Please upgrade to latest distro version"% (list_scanjet[0],list_scanjet[1])
        ui.failureMessage(scanjet_error)
        ui.DisableAllScanjet()    '''    
    #obk[0].show()
    #sys.exit(obk[1].exec_())




# -*- coding: utf-8 -*-
#
# (c) Copyright 2001-2015 HP Development Company, L.P.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# Authors: Don Welch
#


# Std Lib
import sys
import os.path
import os
import subprocess

# Local
from base.g import *
from base import utils, magic
from prnt import cups
from base.codes import *
from .ui_utils import *
from base.sixext import to_unicode, to_string_utf8, from_unicode_to_str
# Qt
from PyQt5.QtCore import *
from PyQt5.QtGui import *
from PyQt5.QtWidgets import *

# Other UI
from .mimetypesdialog import MimeTypesDialog


FILETABLE_TYPE_PRINT = 0
FILETABLE_TYPE_FAX = 1



class FileTable(QWidget):

    fileListChanged = pyqtSignal()
    isEmpty = pyqtSignal()
    isNotEmpt = pyqtSignal()

    def __init__(self, parent):
        QWidget.__init__(self, parent)
        self.parent = parent

        self.initUi()
        self.file_list = []
        self.typ = FILETABLE_TYPE_PRINT
        self.selected_filename = None
        self.fax_add_callback = None
        self.allowable_mime_types = cups.getAllowableMIMETypes()

        self.user_settings = UserSettings()
        self.user_settings.load()
        self.user_settings.debug()

        self.working_dir = self.user_settings.working_dir #user_conf.workingDirectory()



    def initUi(self):
        self.gridlayout = QGridLayout(self)
        self.gridlayout.setObjectName("gridlayout")
        self.FileTable = QTableWidget(self)
        self.FileTable.setObjectName("FileTable")
        self.gridlayout.addWidget(self.FileTable,0,0,1,6)
        self.AddFileButton = QPushButton(self)
        self.AddFileButton.setObjectName("AddFileButton")
        self.gridlayout.addWidget(self.AddFileButton,1,0,1,1)
        self.RemoveFileButton = QPushButton(self)
        self.RemoveFileButton.setObjectName("RemoveFileButton")
        self.gridlayout.addWidget(self.RemoveFileButton,1,1,1,1)
        self.MoveFileUpButton = QPushButton(self)
        self.MoveFileUpButton.setObjectName("MoveFileUpButton")
        self.gridlayout.addWidget(self.MoveFileUpButton,1,2,1,1)
        self.MoveFileDownButton = QPushButton(self)
        self.MoveFileDownButton.setObjectName("MoveFileDownButton")
        self.gridlayout.addWidget(self.MoveFileDownButton,1,3,1,1)
        spacerItem = QSpacerItem(91,20,QSizePolicy.Expanding,QSizePolicy.Minimum)
        self.gridlayout.addItem(spacerItem,1,4,1,1)
        self.ShowTypesButton = QPushButton(self)
        self.ShowTypesButton.setObjectName("ShowTypesButton")
        self.gridlayout.addWidget(self.ShowTypesButton,1,5,1,1)
        self.AddFileButton.setText(self.__tr("Add..."))
        self.AddFileButton.setIcon(QIcon(load_pixmap('list_add', '16x16')))
        self.AddFileButton.clicked.connect(self.AddFileButton_clicked)
        self.RemoveFileButton.setIcon(QIcon(load_pixmap('list_remove', '16x16')))
        self.RemoveFileButton.setText(self.__tr("Remove"))
        self.RemoveFileButton.clicked.connect(self.RemoveFileButton_clicked)
        self.MoveFileUpButton.setText(self.__tr("Move Up"))
        self.MoveFileUpButton.setIcon(QIcon(load_pixmap('up', '16x16')))
        self.MoveFileUpButton.clicked.connect(self.MoveFileUpButton_clicked)
        self.MoveFileDownButton.setText(self.__tr("Move Down"))
        self.MoveFileDownButton.setIcon(QIcon(load_pixmap('down', '16x16')))
        self.MoveFileDownButton.clicked.connect(self.MoveFileDownButton_clicked)
        self.ShowTypesButton.setText(self.__tr("Show Valid Types..."))
        self.ShowTypesButton.setIcon(QIcon(load_pixmap('mimetypes', '16x16')))
        self.ShowTypesButton.clicked.connect(self.ShowTypesButton_clicked)
        self.FileTable.setContextMenuPolicy(Qt.CustomContextMenu)
        #self.connect(self.FileTable, SIGNAL("customContextMenuRequested(const QPoint &)"),
        #    self.FileTable_customContextMenuRequested)
        self.FileTable.customContextMenuRequested["const QPoint &"].connect(self.FileTable_customContextMenuRequested)
        self.headers = [self.__tr("Name"), self.__tr("Type"), self.__tr("Folder/Path")]

        self.FileTable.setSortingEnabled(False)
        self.FileTable.itemSelectionChanged.connect(self.FileTable_itemSelectionChanged)


    def setWorkingDir(self, d):
        if os.path.exists(d):
            self.working_dir = d


    def getWorkingDir(self):
        if self.file_list:
            self.working_dir = os.path.pathname(self.file_list[0][0])
            #user_conf.setWorkingDirectory(self.working_dir)
            self.user_settings.working_dir = self.working_dir
            self.user_settings.save()

        return self.working_dir


    def setType(self, t):
        self.typ = t
        if self.typ == FILETABLE_TYPE_FAX:
            self.headers = [self.__tr("Name"), self.__tr("Type"), self.__tr("Pages")]
            if log.is_debug():
                self.headers.append(self.__tr("File"))


    def setFaxCallback(self, callback):
        self.fax_add_callback = callback


    def isNotEmpty(self):
        return len(self.file_list)


    def FileTable_itemSelectionChanged(self):
        self.selected_filename = self.currentFilename()
        self.setUpDownButtons()


    def updateUi(self, show_add_file_if_empty=True):
        self.FileTable.clear()
        self.FileTable.setRowCount(len(self.file_list))
        self.FileTable.setColumnCount(0)

        if self.file_list:
            # self.emit(SIGNAL("isNotEmpty"))
            self.isNotEmpt.emit()
            QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
            try:
                selected = None
                self.FileTable.setColumnCount(len(self.headers))
                self.FileTable.setHorizontalHeaderLabels(self.headers)
                flags = Qt.ItemIsSelectable | Qt.ItemIsEnabled

                for row, f in enumerate(self.file_list):
                    filename, mime_type, mime_type_desc, title, num_pages = f
                    col = 0

                    if self.typ == FILETABLE_TYPE_FAX:
                        if title:
                            i = QTableWidgetItem(title)
                        else:
                            i = QTableWidgetItem(os.path.basename(filename))
                    else: # FILETABLE_TYPE_PRINT
                        # Filename (basename)
                        i = QTableWidgetItem(os.path.basename(filename))

                    i.setData(Qt.UserRole, to_unicode(filename))
                    i.setFlags(flags)

                    if self.selected_filename is not None and \
                        self.selected_filename == filename:
                        selected = i

                    self.FileTable.setItem(row, col, i)
                    col += 1

                    # MIME type
                    i = QTableWidgetItem(mime_type_desc)
                    i.setFlags(flags)
                    self.FileTable.setItem(row, col, i)
                    col += 1

                    if self.typ == FILETABLE_TYPE_PRINT:
                        # path/folder
                        i = QTableWidgetItem(os.path.dirname(filename))
                        i.setFlags(flags)
                        self.FileTable.setItem(row, col, i)
                        col += 1

                    if self.typ == FILETABLE_TYPE_FAX:
                        # num pages
                        if num_pages < 1:
                            i = QTableWidgetItem(self.__tr("(unknown)"))
                        else:
                            i = QTableWidgetItem(to_unicode(num_pages))
                        i.setFlags(flags)
                        self.FileTable.setItem(row, col, i)
                        col += 1

                        if self.typ == FILETABLE_TYPE_FAX and log.is_debug():
                            i = QTableWidgetItem(filename)
                            i.setFlags(flags)
                            self.FileTable.setItem(row, col, i)


                self.FileTable.resizeColumnsToContents()

                if selected is None:
                    selected = self.FileTable.item(0, 0)

                selected.setSelected(True)
                self.FileTable.setCurrentItem(selected)

            finally:
                QApplication.restoreOverrideCursor()

            self.RemoveFileButton.setEnabled(True)
            self.RemoveFileButton.setIcon(QIcon(load_pixmap('list_remove', '16x16')))

            self.setUpDownButtons()

        else:
            # self.emit(SIGNAL("isEmpty"))
            self.isEmpty.emit()
            self.RemoveFileButton.setEnabled(False)
            self.setUpDownButtons()

            if show_add_file_if_empty:
                # self.AddFileButton.emit(SIGNAL("clicked()"))
                self.AddFileButton.clicked.emit()


    def setUpDownButtons(self):
        if self.file_list:
            i = self.FileTable.currentRow()

            if len(self.file_list) > 1 and i != len(self.file_list)-1:
                self.MoveFileDownButton.setEnabled(True)
            else:
                self.MoveFileDownButton.setEnabled(False)

            if len(self.file_list) > 1 and i != 0:
                self.MoveFileUpButton.setEnabled(True)
            else:
                self.MoveFileUpButton.setEnabled(False)

        else:
            self.MoveFileDownButton.setEnabled(False)
            self.MoveFileUpButton.setEnabled(False)


    def AddFileButton_clicked(self):
        if self.typ == FILETABLE_TYPE_PRINT:
            s = self.__tr("Select File(s) to Print")
        else:
            stat = ''
            try :
                p = subprocess.Popen('getenforce', stdout=subprocess.PIPE, stderr=subprocess.PIPE)
                stat, err = p.communicate()
                stat = to_string_utf8(stat)
            except OSError :
                pass
            except :
                log.exception()
            # if stat.strip('\n') == 'Enforcing' :
            #     FailureUI(self, self.__tr("<b>Unable to add file. Please disable SeLinux.</b><p>Either disable it manually or run hp-doctor from terminal.</p>"),
            #         self.__tr("HP Device Manager"))
            #     return

            s = self.__tr("Select File(s) to Send")

        files = QFileDialog.getOpenFileNames(self, s, self.working_dir, self.__tr("All files (*)"))

        files = [to_unicode(f) for f in files[0]]
        # log.error(files)
        if files:
            self.addFileList(files)

            if self.typ == FILETABLE_TYPE_PRINT:
                self.updateUi(False)


    def addFileList(self, file_list):
        for f in file_list:
            self.addFileFromUI(f)


    def addFileFromUI(self, f, title='', num_pages=0):
        f = os.path.abspath(os.path.expanduser(f))
        log.debug("Trying to add file: %s" % f)
        if os.path.exists(f) and os.access(f, os.R_OK):
            mime_type = magic.mime_type(f)
            mime_type_desc = mime_type
            log.debug("File type of file %s: %s" % (f, mime_type))
            try:
                mime_type_desc = MIME_TYPES_DESC[mime_type][0]
            except KeyError:
                if self.typ == FILETABLE_TYPE_PRINT:
                    FailureUI(self, self.__tr("<b>You are trying to add a file  that cannot be directly printed with this utility.</b><p>To print this file, use the print command in the application that created it.<p>Note: Click <i>Show Valid Types...</i> to view a list of compatible file types that can be directly printed from this utility."),
                        self.__tr("HP Device Manager"))
                else:
                    FailureUI(self, self.__tr("<b>You are trying to add a file  that cannot be directly faxed with this utility.</b><p>To fax this file, use the print command in the application that created it (using the appropriate fax print queue).<p>Note: Click <i>Show Valid Types...</i> to view a list of compatible file types that can be directly added to the fax file list in this utility."),
                        self.__tr("HP Device Manager"))
            else:
                if self.typ == FILETABLE_TYPE_PRINT:
                    self.addFile(f, mime_type, mime_type_desc, title, num_pages)
                else:
                    self.fax_add_callback(f)
        else:
            FailureUI(self, self.__tr("<b>Unable to add file '%s' to file list (file not found or insufficient permissions).</b><p>Check the file name and try again."%f),
                      self.__tr("HP Device Manager"))


    def addFile(self, f, mime_type, mime_type_desc, title, num_pages):
        log.debug("Adding file %s (%s,%s,%s,%d)" % (f, mime_type, mime_type_desc, title, num_pages))
        self.file_list.append((f, mime_type, mime_type_desc, title, num_pages))
        self.updateUi()
        # self.emit(SIGNAL("fileListChanged"))
        self.fileListChanged.emit()


    def currentFilename(self):
        i = self.FileTable.item(self.FileTable.currentRow(), 0)
        if i is None:
            return None

        return value_str(i.data(Qt.UserRole))


    def RemoveFileButton_clicked(self):
        filename = self.currentFilename()
        if filename is None:
            return

        return self.removeFile(filename)


    def removeFile(self, filename):
        temp = self.file_list[:]
        index = 0
        for f, mime_type, mime_type_desc, title, num_pages in temp:
            if f == to_unicode(filename):
                del self.file_list[index]
                # self.emit(SIGNAL("fileListChanged"))
                self.fileListChanged.emit()
                self.updateUi(False)
                break
            index += 1


    def removeFileByMIMEType(self, mime_type):
        temp = self.file_list[:]
        index = 0
        for filename, m, mime_type_desc, title, num_pages in temp:
            if m == mime_type:
                del self.file_list[index]
                # self.emit(SIGNAL("fileListChanged"))
                self.fileListChanged.emit()
                self.updateUi(False)
                break
            index += 1


    def isMIMETypeInList(self, mime_type):
        for filename, m, mime_type_desc, title, num_pages in self.file_list:
            if m == mime_type:
                return True

        return False


    def ShowTypesButton_clicked(self):
        x = {}
        for a in self.allowable_mime_types:
            x[a] = MIME_TYPES_DESC.get(a, ('Unknown', 'n/a'))

        dlg = MimeTypesDialog(x, self)
        dlg.exec_()


    def MoveFileUpButton_clicked(self):
        filename = self.currentFilename()
        if filename is None:
            return

        utils.list_move_up(self.file_list, filename, self.__compareFilenames)
        self.updateUi()


    def MoveFileDownButton_clicked(self):
        filename = self.currentFilename()
        if filename is None:
            return

        utils.list_move_down(self.file_list, filename, self.__compareFilenames)
        self.updateUi()


    def __compareFilenames(self, a, b):
        return a[0] == b


    def FileTable_customContextMenuRequested(self, p):
        print(p)


    def __tr(self,s,c = None):
        return qApp.translate("FileTable",s,c)






# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui5/plugindialog_base.ui'
#
# Created by: PyQt5 UI code generator 5.4.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(700, 500)
        self.gridlayout = QtWidgets.QGridLayout(Dialog)
        self.gridlayout.setObjectName("gridlayout")
        self.StackedWidget = QtWidgets.QStackedWidget(Dialog)
        self.StackedWidget.setObjectName("StackedWidget")
        self.page = QtWidgets.QWidget()
        self.page.setObjectName("page")
        self.gridlayout1 = QtWidgets.QGridLayout(self.page)
        self.gridlayout1.setObjectName("gridlayout1")
        self.label = QtWidgets.QLabel(self.page)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.gridlayout1.addWidget(self.label, 0, 0, 1, 1)
        self.line = QtWidgets.QFrame(self.page)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.gridlayout1.addWidget(self.line, 1, 0, 1, 2)
        self.TitleLabel = QtWidgets.QLabel(self.page)
        self.TitleLabel.setWordWrap(True)
        self.TitleLabel.setObjectName("TitleLabel")
        self.gridlayout1.addWidget(self.TitleLabel, 2, 0, 1, 2)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridlayout1.addItem(spacerItem, 3, 0, 1, 1)
        self.groupBox = QtWidgets.QGroupBox(self.page)
        self.groupBox.setObjectName("groupBox")
        self.gridlayout2 = QtWidgets.QGridLayout(self.groupBox)
        self.gridlayout2.setObjectName("gridlayout2")
        self.DownloadRadioButton = QtWidgets.QRadioButton(self.groupBox)
        self.DownloadRadioButton.setChecked(True)
        self.DownloadRadioButton.setObjectName("DownloadRadioButton")
        self.gridlayout2.addWidget(self.DownloadRadioButton, 0, 0, 1, 2)
        self.CopyRadioButton = QtWidgets.QRadioButton(self.groupBox)
        self.CopyRadioButton.setEnabled(True)
        self.CopyRadioButton.setObjectName("CopyRadioButton")
        self.gridlayout2.addWidget(self.CopyRadioButton, 1, 0, 1, 2)
        spacerItem1 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout2.addItem(spacerItem1, 2, 0, 1, 1)
        self.hboxlayout = QtWidgets.QHBoxLayout()
        self.hboxlayout.setObjectName("hboxlayout")
        self.PathLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.PathLineEdit.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.PathLineEdit.sizePolicy().hasHeightForWidth())
        self.PathLineEdit.setSizePolicy(sizePolicy)
        self.PathLineEdit.setObjectName("PathLineEdit")
        self.hboxlayout.addWidget(self.PathLineEdit)
        self.BrowseToolButton = QtWidgets.QToolButton(self.groupBox)
        self.BrowseToolButton.setEnabled(False)
        self.BrowseToolButton.setText("")
        self.BrowseToolButton.setObjectName("BrowseToolButton")
        self.hboxlayout.addWidget(self.BrowseToolButton)
        self.gridlayout2.addLayout(self.hboxlayout, 2, 1, 1, 1)
        self.SkipRadioButton = QtWidgets.QRadioButton(self.groupBox)
        self.SkipRadioButton.setObjectName("SkipRadioButton")
        self.gridlayout2.addWidget(self.SkipRadioButton, 3, 0, 1, 2)
        self.gridlayout1.addWidget(self.groupBox, 4, 0, 1, 2)
        spacerItem2 = QtWidgets.QSpacerItem(278, 51, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridlayout1.addItem(spacerItem2, 5, 1, 1, 1)
        self.StackedWidget.addWidget(self.page)
        self.gridlayout.addWidget(self.StackedWidget, 0, 0, 1, 5)
        self.line_2 = QtWidgets.QFrame(Dialog)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.gridlayout.addWidget(self.line_2, 1, 0, 1, 5)
        self.StepText = QtWidgets.QLabel(Dialog)
        self.StepText.setObjectName("StepText")
        self.gridlayout.addWidget(self.StepText, 2, 0, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(161, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout.addItem(spacerItem3, 2, 1, 1, 1)
        self.BackButton = QtWidgets.QPushButton(Dialog)
        self.BackButton.setEnabled(False)
        self.BackButton.setObjectName("BackButton")
        self.gridlayout.addWidget(self.BackButton, 2, 2, 1, 1)
        self.NextButton = QtWidgets.QPushButton(Dialog)
        self.NextButton.setObjectName("NextButton")
        self.gridlayout.addWidget(self.NextButton, 2, 3, 1, 1)
        self.CancelButton = QtWidgets.QPushButton(Dialog)
        self.CancelButton.setObjectName("CancelButton")
        self.gridlayout.addWidget(self.CancelButton, 2, 4, 1, 1)

        self.retranslateUi(Dialog)
        self.StackedWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "HP Device Manager - Plug-in Installer"))
        self.label.setText(_translate("Dialog", "Driver Plug-in Installation"))
        self.TitleLabel.setText(_translate("Dialog", "You may download the plug-in directly from an HP authorized server, or, if you already have a local copy of the plug-in file, you can specify a path to the file."))
        self.groupBox.setTitle(_translate("Dialog", "Plug-in Installation Choice"))
        self.DownloadRadioButton.setText(_translate("Dialog", "Download and install the plug-in from an HP authorized server (recommended)"))
        self.CopyRadioButton.setText(_translate("Dialog", "Select and install an existing local copy of the plug-in file (advanced):"))
        self.BrowseToolButton.setToolTip(_translate("Dialog", "Open a local copy of the plug-in file"))
        self.SkipRadioButton.setText(_translate("Dialog", "Skip installation of the plug-in (not recommended)"))
        self.StepText.setText(_translate("Dialog", "Step %d of %d"))
        self.BackButton.setText(_translate("Dialog", "< Back"))
        self.NextButton.setText(_translate("Dialog", "Next >"))
        self.CancelButton.setText(_translate("Dialog", "Cancel"))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui5/printsettingsdialog_base.ui'
#
# Created by: PyQt5 UI code generator 5.4.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.setWindowModality(QtCore.Qt.ApplicationModal)
        Dialog.resize(700, 500)
        self.gridlayout = QtWidgets.QGridLayout(Dialog)
        self.gridlayout.setObjectName("gridlayout")
        self.TitleLabel = QtWidgets.QLabel(Dialog)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.TitleLabel.setFont(font)
        self.TitleLabel.setObjectName("TitleLabel")
        self.gridlayout.addWidget(self.TitleLabel, 0, 0, 1, 1)
        self.line = QtWidgets.QFrame(Dialog)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.gridlayout.addWidget(self.line, 1, 0, 1, 2)
        self.PrinterName = PrinterNameComboBox(Dialog)
        self.PrinterName.setObjectName("PrinterName")
        self.gridlayout.addWidget(self.PrinterName, 2, 0, 1, 2)
        self.OptionsToolBox = PrintSettingsToolbox(Dialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.OptionsToolBox.sizePolicy().hasHeightForWidth())
        self.OptionsToolBox.setSizePolicy(sizePolicy)
        self.OptionsToolBox.setObjectName("OptionsToolBox")
        self.gridlayout.addWidget(self.OptionsToolBox, 3, 0, 1, 2)
        spacerItem = QtWidgets.QSpacerItem(461, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout.addItem(spacerItem, 4, 0, 1, 1)
        self.CloseButton = QtWidgets.QPushButton(Dialog)
        self.CloseButton.setObjectName("CloseButton")
        self.gridlayout.addWidget(self.CloseButton, 4, 1, 1, 1)

        self.retranslateUi(Dialog)
        self.OptionsToolBox.setCurrentIndex(-1)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "HP Device Manager - Print Settings"))
        self.TitleLabel.setText(_translate("Dialog", "Print Settings"))
        self.CloseButton.setText(_translate("Dialog", "Close"))

from .printernamecombobox import PrinterNameComboBox
from .printsettingstoolbox import PrintSettingsToolbox



# -*- coding: utf-8 -*-
#
# (c) Copyright 2001-2015 HP Development Company, L.P.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# Author: Don Welch
#

# Std Lib

# Local
from base.g import *
from .ui_utils import *
from base import device
from base.sixext import  to_unicode

# Qt
from PyQt5.QtCore import *
from PyQt5.QtGui import *
from PyQt5.QtWidgets import *


DEVICEURICOMBOBOX_TYPE_PRINTER_ONLY = 0
DEVICEURICOMBOBOX_TYPE_FAX_ONLY = 1
DEVICEURICOMBOBOX_TYPE_PRINTER_AND_FAX = 2


class DeviceUriComboBox(QWidget):
    DeviceUriComboBox_oneDevice = pyqtSignal()
    DeviceUriComboBox_noDevices = pyqtSignal()
    DeviceUriComboBox_currentChanged = pyqtSignal(str)
    def __init__(self, parent):
        QWidget.__init__(self, parent)
        self.device_uri = ''
        self.initial_device = None
        self.updating = False
        self.typ = DEVICEURICOMBOBOX_TYPE_PRINTER_ONLY
        self.filter = None
        self.devices = None

        self.user_settings = UserSettings()
        self.user_settings.load()
        self.user_settings.debug()

        self.initUi()


    def initUi(self):
        HBoxLayout = QHBoxLayout(self)
        HBoxLayout.setObjectName("HBoxLayout")

        self.NameLabel = QLabel(self)
        self.NameLabel.setObjectName("NameLabel")
        HBoxLayout.addWidget(self.NameLabel)

        SpacerItem = QSpacerItem(20, 20, QSizePolicy.Minimum, QSizePolicy.Minimum)
        HBoxLayout.addItem(SpacerItem)

        self.ComboBox = QComboBox(self)
        sizePolicy = QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ComboBox.sizePolicy().hasHeightForWidth())
        self.ComboBox.setSizePolicy(sizePolicy)
        self.ComboBox.setObjectName("ComboBox")
        HBoxLayout.addWidget(self.ComboBox)

        self.NameLabel.setText(self.__tr("Device:"))

#        self.connect(self.ComboBox, SIGNAL("currentIndexChanged(int)"),
#            self.ComboBox_currentIndexChanged)

        # self.connect(self.ComboBox, SIGNAL("currentIndexChanged(const QString &)"),
        #     self.ComboBox_currentIndexChanged)
        self.ComboBox.currentIndexChanged["const QString &"].connect(self.ComboBox_currentIndexChanged)

    def setType(self, typ):
        if typ in (DEVICEURICOMBOBOX_TYPE_PRINTER_ONLY,
                   DEVICEURICOMBOBOX_TYPE_FAX_ONLY,
                   DEVICEURICOMBOBOX_TYPE_PRINTER_AND_FAX):
            self.typ = typ


    def setFilter(self, filter):
        self.filter = filter


    def setInitialDevice(self, device_uri):
        self.initial_device = device_uri


    def setDevices(self):
        if self.typ == DEVICEURICOMBOBOX_TYPE_PRINTER_ONLY:
            be_filter = ['hp']

        elif self.typ == DEVICEURICOMBOBOX_TYPE_FAX_ONLY:
            be_filter = ['hpfax']
            self.NameLabel.setText(self.__tr("Fax Device:"))

        else: # DEVICEURICOMBOBOX_TYPE_PRINTER_AND_FAX
            be_filter = ['hp', 'hpfax']

        self.devices = device.getSupportedCUPSDevices(be_filter, self.filter)
        return len(self.devices)


    def updateUi(self):
        if self.devices is None:
            self.setDevices()

        self.device_index = {}

        if self.devices:
            if self.initial_device is None:
                #self.initial_device = user_conf.get('last_used', 'device_uri')
                self.initial_device = self.user_settings.last_used_device_uri

            self.updating = True
            try:
                k = 0
                for i, d in enumerate(self.devices):
                    self.ComboBox.insertItem(i, d)

                    if self.initial_device is not None and d == self.initial_device:
                        self.initial_device = None
                        k = i

                self.ComboBox.setCurrentIndex(-1)
            finally:
                self.updating = False

            self.ComboBox.setCurrentIndex(k)

            if len(self.devices) == 1:
                # self.emit(SIGNAL("DeviceUriComboBox_oneDevice"))
                self.DeviceUriComboBox_oneDevice.emit()

        else:
            # self.emit(SIGNAL("DeviceUriComboBox_noDevices"))
            self.DeviceUriComboBox_noDevices.emit()

    def ComboBox_currentIndexChanged(self, t):
        if self.updating:
            return

        self.device_uri = to_unicode(t)
        if self.device_uri:
            #user_conf.set('last_used', 'device_uri', self.device_uri)
            self.user_settings.last_used_device_uri = self.device_uri
            self.user_settings.save()

            # self.emit(SIGNAL("DeviceUriComboBox_currentChanged"), self.device_uri)
            self.DeviceUriComboBox_currentChanged.emit(self.device_uri)

    def __tr(self,s,c = None):
        return qApp.translate("DeviceUriComboBox",s,c)



# -*- coding: utf-8 -*-
#
# (c) Copyright 2001-2015 HP Development Company, L.P.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# Author: Don Welch
#

# Local
from base.g import *
from base.codes import *
from .ui_utils import *

# Qt
from PyQt5.QtCore import *
from PyQt5.QtGui import *
from PyQt5.QtWidgets import *
from .mimetypesdialog_base import Ui_MimeTypesDialog_base



class MimeTypesDialog(QDialog, Ui_MimeTypesDialog_base):
    def __init__(self, mime_types, parent=None):
        QDialog.__init__(self, parent)
        self.setupUi(self)

        self.TypesTableWidget.setRowCount(len(mime_types))
        t = list(mime_types.keys())
        t.sort()
        for row, m in enumerate(t):
            i = QTableWidgetItem(m)
            self.TypesTableWidget.setItem(row, 0, i)

            i = QTableWidgetItem(mime_types[m][0])
            self.TypesTableWidget.setItem(row, 1, i)

            i = QTableWidgetItem(mime_types[m][1])
            self.TypesTableWidget.setItem(row, 2, i)

        self.TypesTableWidget.resizeColumnsToContents()


    def __tr(self,s,c = None):
        return qApp.translate("SettingsDialog",s,c)


